%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%---- Writing FM input file  for inversion------------------
%--------------------------------------------------------------------------
%File format
% NBmf NBnp
% str dp rk
% inp1 inp2
% jklm sigmi
% n1 n2 n3 n4
% psi
% phi
% teta
% R
%%
% NBmf: number of focal mechanisms (FM)
% NBnp: number of known fault planes
% str, dp, rk: strike, dip rake for each FM, the FM with a known fault palne must be written first
% inp1, inp2 : uncertainty on the 1st nodal plane and 2nd nodal plane (the 1st nodal plane is the one indicated on the lines above)
% jklm: ponderation in function of the uncertainty on the nodal pane (jklm=2) or not (jklm=1)
% sigmi: uncertainty due to the media heterogeneity
% n1, n2, n3, n4: grid dimensions, n1=n2=n3 the angular increment is the same for each angular parameter
% psi: values of psi to search between 0 and 180 (n1=number of values)
% phi: values of phi to search between 0 and 180
% teta: values of teta to search between 0 and 180
% R: values of R to search between 0 and 1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [out_put] = Inv_entree(in_put)
out_put = in_put;
pc = 0;
if in_put.inv==1
%%% keep only the event not excluded by the volume criterion
  st1 = in_put.st(in_put.id);
  dp1 = in_put.dp(in_put.id);
  rk1 = in_put.rk(in_put.id);
  errp = in_put.erp1(in_put.id);
  erra = in_put.erp2(in_put.id);
%%%% magnitude min criterion
  if in_put.mag_coup~=0
    m=in_put.mw(in_put.id);
    idc = find(m>=in_put.mag_coup);
    L = length(idc);
  else
    L = length(in_put.id);
    idc=1:L;
  end
  fid = fopen(in_put.nomout,'wt');
  fprintf(fid,'%d %d\n', L,pc);%nb of FM and known fault planes
% 
  for i=1:length(st1)
    if st1(i)>360
      st1(i)=st1(i)-360;
    end
    if rk1(i)>180
      rk1(i)=rk1(i)-360;
    end
  end
%%% MF parameters (strike, dip, rake)
    for i=1:L
        j=idc(i);
        fprintf(fid,'%5.1f %5.1f %5.1f \n',st1(j),dp1(j),rk1(j));
    end
%%% grid for the search and other parameters
    psi = 0:in_put.ang:180;
    phi = psi;
    tet = psi;
    ang = [psi; phi; tet];
    r = 0:in_put.dr:1;
    D = length(phi);
    dd = length(r);
    dim=[D D D dd];
%%%
    for i=1:L
        j=idc(i);
        fprintf(fid,'%d %d \n', errp(j), erra(j));
    end
    jk=in_put.jklm;
    sig=in_put.sigmi;
else
  nom2=[in_put.nomout 'i' num2str(in_put.inv)];
  fid = fopen(nom2,'wt');
  fii = fopen(in_put.nomout,'r');
  c=textscan(fii,'%f %f',1);
  L=c{1};
  c=textscan(fii,'%f %f %f',L);
  st=c{1};
  dp=c{2};
  rk=c{3};
  c=textscan(fii,'%d %d',L);
  std1=c{1};
  std2=c{2};
  c=textscan(fii,'%d %d',1);
  jk=c{1};
  sig=c{2};
  fclose(fii);
  %%%
  fprintf(fid,'%d %d\n',L,pc);
  for i=1:L
    fprintf(fid,'%5.1f %5.1f %5.1f \n',st(i),dp(i),rk(i));
  end
  for i=1:L
    fprintf(fid,'%d %d\n',std1(i),std2(i));
  end
  %%%
  eul=in_put.p22out;
  fie=fopen(eul,'r');
  c=textscan(fie,'%f %f %f %f');
  fclose(fie);
  psi = c{1};
  phi = c{2};
  tet = c{3};
  ang = [psi; phi; tet];
  r = c{4};
  D = 1;
  dd = 1;
  dim=[D D D dd]; 
end
fprintf(fid,'%d %d \n',jk,sig);
fprintf(fid,'%d %d %d %d \n',dim(1),dim(2),dim(3),dim(4));
for j=1:3
  for i=1:dim(1)
    fprintf(fid,'%d ',ang(j,i));
  end
  fprintf(fid,'\n');
end
for i=1:dim(4)
  fprintf(fid,'%2.2f ',r(i));
end
fclose(fid);
