function [out_put]=exclusion(in_put)
out_put = in_put;
%look for earthquakes too close to previous ones
%First, calcul of the rupture radius from Pearson (1982) relation. 
%From this rupture radius, r, an exclusion volume is determined of radius R=RFAC*r
%Then calcul of the distance, dist, between an event and all the previous events.
%The distance calculation is based on equirectangular approximation (see
%http://www.movable-type.co.uk/scripts/latlong.html ). Since the event are from a seismic crisis 
%they are near each other and a simple calcul is enough
%If any previous event occurred within the volume of radius R, the event is excluded.
%For more information see Maury et al, 2013 BSGF, 184, n°4-5
%
%%%INPUT X,Y,Z : lat,lon,depth; m magnitude Mw; RFAC factor to determine the extent of the exclusion volume
%%% suggested value RFAC=1 exclusion limited to the volume of the earthquake or RFAC=2
%%%OUTPUT id: id of events not excluded; dmin: min(dist-R); evt: previous evt that is the nearest from 
%%% the considered event; RE: radius of the exclusion volume
%
%initialize
fid=fopen(in_put.nomea,'r');
c=textscan(fid,'%d %d %d %d %d %f %f %f %f %f %f %s','headerlines',1);
fclose(fid);
X=c{7};
Y=c{8};
Z=c{9}*1000;
m=c{11};
mf=c{12};
L=length(X);
X=X*pi/180;
Y=Y*pi/180;
RT=6371000;
%calcul of the radius and distance
lm=3/2*(m+10.7);%Hanks and Kanamori (1979) relation
r = 10.^(0.33.*lm-4.18);%Pearson (1982) relation
dist = 1e4*ones(L-1,L-1);
crit = 1e4*ones(L-1,L-1);
R=zeros(L,1);
R(1)=in_put.RFAC*r(1);
for i=2:L
    R(i)=in_put.RFAC*r(i);
    for j=1:(i-1)
        x=(Y(i)-Y(j))*cos((X(i)+X(j))/2);
        y=X(i)-X(j);
        z=Z(i)-Z(j);
        dist(j,i) = sqrt((RT*x)^2+(RT*y)^2+z^2);
        crit(j,i) = dist(j,i)-R(i);
    end
end
%exclusion
id=zeros(L,1);
id(1)=1;
cmin=zeros(L,1);
k=2;
for i=2:L
    critm=min(crit(:,i));
    cmin(i)=critm;
    if (critm>=0)
        id(k) =i;
        k=k+1;
    end
end
k=k-1;
id=id(1:k);
%check what FM are kept
cpt=-9*ones(L,1);
ic=1;
for i=1:L
    if strcmp(char(mf(i,:)),'F')
       cpt(i)=ic;
       ic=ic+1;
    end
end
idm=zeros(L,1);
kk=1;
for i=1:length(id)
    if strcmp(char(mf(id(i),:)),'F')
      idm(kk)=cpt(id(i));
      kk=kk+1;
    endif
end
kk=kk-1;
idm=idm(1:kk);
%
plot(cmin,R,'*k',cmin(id),R(id),'ob')
title('Exclusion radius in function of the exclusion criterion')
xlabel('Rmin-Rad')
ylabel('Radius')
legend('Whole dataset','Final dataset')
%
out_put.id=idm;
out_put.idtot=id;
out_put.dmin=cmin;
out_put.RE=R;
