cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c-------- Principal stress evaluation from focal mechanisms inversion -------------c
c
c   approximative method modified version of Gephart and Forsyth (1984) method
c   initial version Ph Julien, F.H. Cornet (Julien and Cornet, 1987)
c   modification by R. Prioul (Marsh, 2000) of the code not the algorithms
c   modification J. Maury of the code not the algorithms: addition of 
c   retsrictions on the stress directions if needed (assumption of a vertical principal 
c   stress) and modification of the code
ccc
c   1-reading of the data,
c   2-application of the restriction on the grid search if necessary,
c   3-calculation of the rotation angle necessary to fit the MF to each stress tensor and 
c   of the corresponding misfit ,
c   4-find the stress tensor corresponding to the minimum global misfit
c   5-estimation of the confidence limits corresponding to this best stress tensor
c   6-find the remaining best stress tensors (best in the sense of the reduced misfit) explainining 
c   the maximum number of MF
ccc
c   input parameters: name of an input file (XXX) and restrictions on the principal 
c   stress (choose whether or not to impose a vertical principal stress and if a 
c   retsriction on the search domain of s1 or s3 is imposed)
c   input file format: cf Inv_entree.m
c   output files: 
c     output_XXX: description of the results of the inversion step by step
c     mtens_XXX: best stress tensor, with the first line corresponding to the stress 
c   tensor with the lowest global misfit, and the following lines corresponding to 
c   the stress tensors with the lowest reduced misfit explaining a decreasing number 
c   of FM (see out_put_XXX to obtain the number of FM explained) format:
c   sig1az,sig1p,sig2az,sig2p,sig3az,sig3p,r,psi1,phi1,tet1 (p=angle/vertical)
c     mfoy_XXX: give the initial FM, the recalculated ones and the nodal plane chosen as 
c   fault plane (st1/dp1/rk1_init st1/dp1/rk1_recalc st2/dp2/rk2_init st2/dp2/rk2_recalc
c   rot_angle used rot_angle reject nodal plane selected as fault plane)
c     eul_XXX: euler angles for the 90% confidence limits area
c     sol50_XXX: stress tensors within the 50% confidence limits
c     sol90_XXX: stress tensors within the 90% confidence limits but not the 50% conf. lim.
c     sol95_XXX: stress tensors within the 95% confidence limits but not the 90% conf. lim.
c     tens_XXX: planes not consistent with the best stress tensors explaining the highest number
c   of MF
c     
c     
c                          Meca2tens.f
c                            2014/12
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      module mod1
      implicit none
      real, dimension(200,2,3) :: x
      real, dimension(200,2) :: sigpl
      integer :: m,jklm,l1,l2,l3,l4,restr,vv,N
      real :: sigmi
      real :: pd3,az3mi,az3ma
      SAVE
      end module mod1
c
      module mod2
      implicit none
      real,dimension(91) :: psi1, phi1, tet1
      real,dimension(51) :: r
      SAVE
      end module mod2
c
      module mod3
      implicit none
      character (30) :: filen1,filen2,filen3,filen4,filen5
      character (30) :: filen6,filen7,filen8,filen9
      SAVE
      end module mod3
c
      module mod4
      implicit none
      integer :: lk1=14,lk2=11,lk3=12,lk4=13,lk5=15
      integer :: lk6=16,lk7=17,lk8=18,lk9=19
      SAVE
      end module mod4
c
      module mod5
      implicit none
      real,save :: pi=3.1415926536
      end module mod5
c
      program inversion
      use mod1
      use mod2
      use mod3
      use mod4
      use mod5
      implicit none
c
      integer :: i1,i2,i3,i4,mno,i,j,per,m11,it,k11,mini
      real :: bma,bmi,r2d
      real,dimension(91,91,91,51) :: amisfi,bmisfi
      integer,dimension(91,91,91,51) :: n1
      integer,dimension(200,2) :: val_rot
      integer,dimension(200) :: k1,k2,plan
      integer :: j1,j2,j3,j4,ii1,ii2,ii3,ii4,ifd
      real :: sig1d,sig1p,sig2d,sig2p,sig3d,sig3p,vm50,vm90,vm95
      real :: s1d,s1p,s2d,s2p,s3d,s3p,t1d,t1p,t2d,t2p,t3d,t3p
      real,dimension(200,2) :: df,pf,pif,teto,tetu
cccccccc
      r2d = 180./pi
      n1=0
      amisfi=100
      bmisfi=100
      teto=180
      call input1
      open(lk5,file=filen5)
      open(lk6,file=filen6)
      open(lk7,file=filen7)
cccccccc
c     check for restrictions on the principal stress orientations
      do i1=1,l1
        do i2=1,l2
          do i3=1,l3
            do i4=1,l4
              mno=0
              call euler2map(i1,i2,i3,s1d,s1p,s2d,s2p,s3d,s3p)
c one principal stress is vertical (vv=1) i.e. plunge lower than 20° or not (vv=0)
              if (vv==0 .or. (vv==1 .and. s1p<20) .or. 
     @     (vv==1 .and. s2p<20) .or. (vv==1 .and. s3p<20)) then
c if no restriction calcul the misfit for every grid point
                if (restr==0) then
                  call pbdir(i1,i2,i3,i4,mno,amisfi,bmisfi,teto,n1,
     @                   val_rot,df,pf,pif)
c if a restriction on s1 exists check to see if the point is within the restricted area
                elseif (restr==1 .and. s1p>=pd3) then
                  if ((s1d>=az3mi .and. s1d<=az3ma) .or. 
     @             (s1d>=(az3mi+180) .and. s1d<=(az3ma+180))) then
c calculate the misfit 
                    call pbdir(i1,i2,i3,i4,mno,amisfi,bmisfi,teto,n1,
     @                   val_rot,df,pf,pif)
                  endif
c if a restriction on s3 exists check to see if the point is within the restricted area
                elseif (restr==3 .and. s2p>=pd3) then
                  if ((s3d>=az3mi .and. s3d<=az3ma) .or. 
     @             (s3d>=(az3mi+180) .and. s3d<=(az3ma+180))) then
c calculate the misfit
                    call pbdir(i1,i2,i3,i4,mno,amisfi,bmisfi,teto,n1,
     @                   val_rot,df,pf,pif)
                  endif
                endif
              endif
            enddo
          enddo
        enddo
      enddo
cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     calculation of the best tensor
c     misfit GLOBAL minimum
cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     error calculation and true estimation of the misifts
      call mina(amisfi,bma,j1,j2,j3,j4)
      call euler2map(j1,j2,j3,sig1d,sig1p,sig2d,sig2p,sig3d,sig3p)
      write(lk6,705) sig1d,sig1p,sig2d,sig2p,sig3d,sig3p,r(j4),
     @     psi1(j1),phi1(j2),tet1(j3)
      call lim_conf(bma,vm50,vm90,vm95)
c     selection of the tensors: writing in separate files
c     50 (=sol50), 90 (=sol90 - sol50), 95 (=sol95 - sol50 - sol90)
c     50 = tensor within the 50% confidence limits
c     90 = tensor within the 90% CL but not the 50% CL
c     95 = tensor within the 95% CL but not the 90% CL
      call selec_in_conf(amisfi,vm50,vm90,vm95,1)
      per = nint((real(n1(j1,j2,j3,j4))/real(m) * 100.))
c
      write(lk5,*) '------------------------------------------'
      write(lk5,*) 'Result : best tensor, global misfit'
      write(lk5,*) '------------------------------------------'
      write(lk5,*) 'Nb of planes ',n1(j1,j2,j3,j4),' expl. data ',
     @     per,' %'
      write(lk5,*) 'Index ',j1,j2,j3,j4
      write(lk5,*) 'Euler ',psi1(j1),phi1(j2),tet1(j3),r(j4)
      write(lk5,*) 'Reduced misfit ',bmisfi(j1,j2,j3,j4),
     @     ' Global misfit ',bma
      write(lk5,*) 'S1,S2,S3,R ',int(sig1d),int(sig1p),int(sig2d),
     @     int(sig2p),int(sig3d),int(sig3p),r(j4)
      write(lk5,*) '50 , 90, 95 % confidence limits ',vm50,vm90,vm95
c     planes not consistents with the best tensor
      write(lk5,*) '*************************************'
      write(lk5,*) 'Consistants Planes'
      write(lk5,*) '*************************************'
      call pl_non_cons(j1,j2,j3,j4)
      write(lk5,*) '**************************************************'
      write(lk5,*) 'Values of the selected and not selec. rotations'
      write(lk5,*) '**************************************************'
      call selec_val_rot(j1,j2,j3,j4,tetu,plan,val_rot)
      do i=1,m
         if (plan(i).eq.1) then
            write(lk5,*) i,' Plane 1 Rot',val_rot(i,1),' Val :',
     @           tetu(i,1) * r2d,' Plane 2 Rot',val_rot(i,2),
     @           ' Val :',tetu(i,2) * r2d
         else
            write(lk5,*) i,' Plane 2 Rot',val_rot(i,2),' Val :',
     @           tetu(i,2) * r2d,' Plane 1 Rot',val_rot(i,1),
     @           ' Val :',tetu(i,1) * r2d
         endif
      enddo
      write(lk5,*) '*************************************'
      write(lk5,*) 'Turned plane '
      write(lk5,*) '*************************************'
      call plan_tourne(j1,j2,j3,j4,df,pf,pif)
      do i=1,m
         do j=1,2
            write(lk5,*) i,' Pl ',j,'d :',df(i,j),' p :',
     @           pf(i,j),' i :',pif(i,j)
         enddo
      enddo
      write(lk7,*) '# ',n1(j1,j2,j3,j4),' Global : Data + recalculated'
      call write_data_recal(tetu,plan,df,pf,pif)
cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     homogeneous tensors estimation with corresponding
c     reduced planes
cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      it=0
      k11=0
      ifd = 0
      open(lk8,file=filen8)
      do m11=m,1,-1
         if (k11.le.5.and.ifd.le.5) then
            do i=1,m
               k1(i) = 0
               k2(i) = 0
            enddo
c     selection of tensors compatible with m11 planes
            call min_comp(m11,n1,bmisfi,bmi,ii1,ii2,ii3,ii4,
     @           ifd,k1,k2)
            if (ifd.ne.0) then
               k11 = k11 + 1
               call euler2map(ii1,ii2,ii3,sig1d,sig1p,sig2d,sig2p,
     @              sig3d,sig3p)
               write(lk6,705) sig1d,sig1p,sig2d,sig2p,sig3d,sig3p,
     @     r(ii4),psi1(ii1),phi1(ii2),tet1(ii3)
               per = nint(real(m11)/real(m) * 100.)
               write(lk5,*) '------------------------------------------'
               write(lk5,*) 'Result : best tensor, reduced misfit '
               write(lk5,*) '------------------------------------------'
               write(lk5,*) 'Number of planes ',m11, ' expl. data ',
     @              per,' %'
               write(lk5,*) 'Number of compatible tensors ',ifd
               write(lk5,*) 'Best tensor :'
               write(lk5,*) 'Index ',ii1,ii2,ii3,ii4
              write(lk5,*) 'Euler + R ',psi1(ii1),phi1(ii2),tet1(ii3),
     @              r(ii4)
               write(lk5,*) 'Reduced misfit ',bmi,' Global misfit ',
     @              amisfi(ii1,ii2,ii3,ii4)
               write(lk5,*) 'S1,S2,S3,R ',int(sig1d),int(sig1p),
     @              int(sig2d),int(sig2p),int(sig3d),int(sig3p),r(j4)
c     writing of planes not consistant with the tensor
               write(lk5,*) '*************************************'
               write(lk5,*) 'Consistant planes '
               write(lk5,*) '*************************************'
               call pl_non_cons(ii1,ii2,ii3,ii4)
               write(lk5,*) '*************************************'
               write(lk5,*) 'Selected rotations values  '
               write(lk5,*) '*************************************'
      
           call selec_val_rot(ii1,ii2,ii3,ii4,tetu,plan,val_rot)
               do i=1,m
                  if (plan(i).eq.1) then
                     write(lk5,*) i,' Plane 1 Rot',val_rot(i,1),
     @                    ' Val :',tetu(i,1) * r2d,' Plane 2 Rot',
     @                    val_rot(i,2),' Val :',tetu(i,2) * r2d
                  else
                     write(lk5,*) i,' Plane 2 Rot',val_rot(i,2),
     @                    ' Val :',tetu(i,2) * r2d,' Plane 1 Rot',
     @                    val_rot(i,1),' Val :',tetu(i,1) * r2d
                  endif
               enddo
               write(lk5,*) '*************************************'
               write(lk5,*) 'Turned planes calculation '
               write(lk5,*) '*************************************'
               call plan_tourne(j1,j2,j3,j4,df,pf,pif)
               do i=1,m
                  do j=1,2
                     write(lk5,*) i,' Pl ',j,'d :',df(i,j),' p :',
     @                    pf(i,j),' i :',pif(i,j)
                  enddo
               enddo
               write(lk7,*) '# ',m11,' Reduced : Data + recalculated'
               call write_data_recal(tetu,plan,df,pf,pif)
               write(lk5,*) '*****************************************'
               write(lk5,*) 'Tensors comp. with',m11,'planes'
               write(lk5,*) 'Nb of times the planes are selected :'
               write(lk5,*) '*****************************************'
               do i=1,m
                  write(lk5,7600) i,k1(i),k2(i)
               enddo
            else
               write(lk5,*)'Not compatible tensor with',m11,' planes'
            endif
         endif
        it = it + 1
      enddo
ccccccccccccccccccccccccccccccccccccccccccccccccccccc
      close(lk5)
      close(lk6)
      close(lk7)
      close(lk8)
 705  format(1x,6(f7.2,1x),f4.2,1x,3(f7.2,1x))
 7600 format('Meca :',i3,' pl 1 selected :',i3,' pl 2 selected :',i3)
      end
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine pbdir : direct problem
c     Rotation angles estimation and estimation of the sum of
c     the minimum angles for 1 tensor and n planes
c       called by : prog. princ.,min_comp,selec_val_rot,plan_tourne,pl_non_cons
c       call      : tens_geo,triedre_meca,first_rot,second_rot,
c                    third_rot,min,minc,misfit
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine pbdir(i1,i2,i3,i4,mno,amisfi,bmisfi,teto,
     @     n1,val_rot,df,pf,pif)
      use mod1
      use mod5
      implicit none
c
      integer i1,i2,i3,i4,mno,i,j
      real,dimension(3,3) :: f,v,b,beta,g
      integer,dimension(200,2) :: val_rot
      real :: somo,somi,teti
      integer,dimension(91,91,91,51) :: n1
      real,dimension(3) :: vn,sn,s
      real,dimension(91,91,91,51) :: amisfi,bmisfi
      real,dimension(200,2) :: teta1,teta2,teta3,teto
      real,dimension(200,2) :: df,pf,pif
c
      n1(i1,i2,i3,i4)=0
      somo=0.
      somi=0.
c     calculation of the tensor f in the geographic coordinates system
      call tens_geo(i1,i2,i3,i4,b,f)
c     loop over every planes
      do 50 i=1,m
        if (i .le. N) then
          j=1
c     Calculation of the trihedron (vn,sn,s) local for a mechanism
c     and of the director cosinus beta
          call triedre_meca(i,j,b,v,vn,sn,s,beta)
c     Rotations
          call first_rot(i,j,beta,i4,v,vn,f,teta1)
          call second_rot(i,j,beta,i4,v,f,teta2)
          call third_rot(i,j,beta,i4,v,s,f,teta3)
c           
          if (mno.eq.0) then
c     simple consistence, the minimum between the 3 angles is taken
            call mini(i,j,teta1,teta2,teta3,teti,val_rot)
          else
c     simple consistence + calculation of the geometries of the turned planes
            call minc(i,j,teta1,teta2,teta3,s,sn,vn,
     @              teti,df,pf,pif)
          endif
          teto(i,j)=teti
          teto(i,2)=2*pi
        else
c     calculation for both nodal planes if the fault plane is not known
          do 51 j=1,2
c     Calculation of the trihedron (vn,sn,s) local for a mechanism
c     and of the director cosinus beta
            call triedre_meca(i,j,b,v,vn,sn,s,beta)
c     Rotations
            call first_rot(i,j,beta,i4,v,vn,f,teta1)
            call second_rot(i,j,beta,i4,v,f,teta2)
            call third_rot(i,j,beta,i4,v,s,f,teta3)
c           
            if (mno.eq.0) then
c     simple consistence, the minimum between the 3 angles is taken
              call mini(i,j,teta1,teta2,teta3,teti,val_rot)
            else
c     simple consistence + calculation of the geometries of the turned planes
              call minc(i,j,teta1,teta2,teta3,s,sn,vn,
     @              teti,df,pf,pif)
            endif
            teto(i,j)=teti
   51     continue
        endif
c
c     global misfits of all the planes
c     somo and somi are incremented every iteration
        call misfit(i,i1,i2,i3,i4,teto,n1,somo,somi,val_rot)
   50   continue
c
c     global misfits of all the tensors
c     amisfi : global misfit 
c     bmisfi : reduced misfit to the compatible planes
      amisfi(i1,i2,i3,i4)=somo
      bmisfi(i1,i2,i3,i4)=somi
c
      return
      end
c----------end of pbdir------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine tens_geo : 
c     calculation of the stress tensor in the  
c     geographic coordinates system
c       called by : pbdir
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine tens_geo(i1,i2,i3,i4,b,f)
      use mod2
      use mod5
      implicit none
c
      integer :: i1,i2,i3,i4,i,j
      real :: psi,phi,tet
      real, dimension(3,3) :: t,b1,b2,b3,c,b,bt,e,f
c
      t=0
      b1=0
      b2=0
      b3=0
      t(3,3)=1
      b1(3,3)=1
      b2(2,2)=1
      b3(1,1)=1
      psi=pi*psi1(i1)/180.
      phi=pi*phi1(i2)/180.
      tet=pi*tet1(i3)/180.
      t(2,2)=r(i4)
      b1(1,1)=cos(psi)
      b1(2,2)=cos(psi)
      b1(2,1)=sin(psi)
      b1(1,2)=-sin(psi)
      b2(1,1)=cos(phi)
      b2(3,3)=cos(phi)
      b2(1,3)=sin(phi)
      b2(3,1)=-sin(phi)
      b3(2,2)=cos(tet)
      b3(3,3)=cos(tet)
      b3(3,2)=sin(tet)
      b3(2,3)=-sin(tet)
	do i=1,3
	 do j=1,3
	    if (abs(b1(i,j)).le.0.00001) b1(i,j)=0.
	    if (abs(b2(i,j)).le.0.00001) b2(i,j)=0.
	    if (abs(b3(i,j)).le.0.00001) b3(i,j)=0.
	 enddo
	enddo
c
c     direct calculation of the tensor in the geographic system
c     of coordinates (f) from the a priori in the principal
c     system of coordinates (t)
c     f=b*t*bt, b is decomposed in 3 successives rotations.
c     c=b1*b2, b=c*b3, d ou b=b1*b2*b3
c
      c=matmul(b1,b2)
      b=matmul(c,b3)
      do i=1,3
	 do j=1,3
	    bt(i,j)=b(j,i)
	 enddo
	enddo
c     e=b*t, f=e*bt, so f=b*t*bt
      e=matmul(b,t)
      f=matmul(e,bt)
c
      return
      end
c----------end of tens_geo------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine triedre_meca : 
c     Calculation of the trihedron (vn,sn,s)
c       called by : pbdir
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine triedre_meca(i,j,b,v,vn,sn,s,beta)
      use mod1
      implicit none
c
      integer :: i,j
      real,dimension(3,3) :: v,beta
      real,dimension(3) :: vn,sn,s
      integer :: ii,k56,l56,i56
      real :: as,bs,som,test
      real,dimension(3,3) :: b
c
c     1st plane : calculation of the trihedron (vn,sn,s)
c         calculation of the normal to the plane vn
      v(1,1)=-sin(x(i,j,1))*sin(x(i,j,2))
      v(2,1)=cos(x(i,j,1))*sin(x(i,j,2))
      v(3,1)=-cos(x(i,j,2))
      do ii=1,3
        if (v(ii,1)>=0.99999) then
          v(ii,1)=1.
	else if (abs(v(ii,1))<=0.00001) then
          v(ii,1)=0.
	else if (v(ii,1)<=-0.99999) then
          v(ii,1)=-1.
        end if
      enddo
      vn(1)=v(1,1)
      vn(2)=v(2,1)
      vn(3)=v(3,1)
c         calculation of the slip on the plane s
      test = cos(x(i,j,1))*cos(x(i,j,3))
      v(1,3)=test+sin(x(i,j,1))*cos(x(i,j,2))*sin(x(i,j,3))
      as=sin(x(i,j,1))*cos(x(i,j,3))
      bs=cos(x(i,j,1))*cos(x(i,j,2))*sin(x(i,j,3))
      v(2,3)=as-bs
      v(3,3)=-sin(x(i,j,2))*sin(x(i,j,3))
      do ii=1,3
        if (v(ii,3)>=0.99999) then
          v(ii,3)=1.
        else if(abs(v(ii,3))<=0.00001) then
          v(ii,3)=0.
        else if (v(ii,3)<=-0.99999) then
          s(ii)=-1.
        end if
      enddo
      s(1)=v(1,3)
      s(2)=v(2,3)
      s(3)=v(3,3)
c         calculation of the 3rd element of the trihedron s ^ vn
      v(1,2)=v(3,1)*s(2)-v(2,1)*s(3)
      v(2,2)=v(1,1)*s(3)-v(3,1)*s(1)
      v(3,2)=v(2,1)*s(1)-s(2)*v(1,1)
      sn(1)=v(1,2)
      sn(2)=v(2,2)
      sn(3)=v(3,2)
c     The column vectors (vn, sn, s) define a change of basis matrix v
c     from the local to the geographic basis 
c     it is known that f = b * t * bt,
c     In the local basis, the tensor s express f  = vt * f * v,
c     if we define beta = vt * b then f = beta * t * betat
c     beta_ij : director cosinus of the vector i of the local basis
c     in relation to the direction j of the eigenvectors basis
      do k56=1,3
        do l56=1,3
	  som=0.
	  do i56=1,3
	    som=som+v(i56,k56)*b(i56,l56)
	  enddo
	  beta(k56,l56)=som
        enddo
      enddo
c
      return
      end
c----------end of triedre_meca------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine first_rot : 
c     1st rotation (axe = normale to the plane)
c       called by : pbdir
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine first_rot(i,j,beta,i4,v,vn,f,teta1)
      use mod2
      use mod5
      implicit none
c 
      integer :: i4,k,i,j
      real,dimension(3,3) :: f,v,beta
      real,dimension(3) :: vn,sp,s1p,g,vnf
      real,dimension(200,2) :: teta1
      real :: rnum,den,rap,teta,h,tnvnf,soma
c
      rnum=beta(1,3)*beta(2,3)+r(i4)*beta(1,2)*beta(2,2)
c
      den=r(i4)*beta(1,2)*beta(3,2)+beta(1,3)*beta(3,3)
      if (den.eq.0.) then
        teta=pi/2.
      else
        rap=-rnum/den
        teta=atan(rap)
      endif
c     angle teta : Cf article Julien and Cornet, 1987
      s1p(1)=0.
      s1p(2)=-sin(teta)
      s1p(3)=cos(teta)
c     sp = v * sp1
      sp=matmul(v,s1p)
c     g = f * vn force acting on the fault plane
      g=matmul(f,vn)
c     h = vn.g projection of g on vn
      h=vn(1)*g(1)+vn(2)*g(2)+vn(3)*g(3)
      do k=1,3
c     vnf = g - (vn.g)vn : difference vector between g and vn
        vnf(k)=g(k)-h*vn(k)
      enddo
      tnvnf=sqrt(vnf(1)**2+vnf(2)**2+vnf(3)**2)
      if (tnvnf.lt.0.0000025) then
        teta1(i,j)=2.*pi
      else
        soma=0
        do k=1,3
	  vnf(k)=vnf(k)/tnvnf
c     soma = vnf.sp
	  soma=soma+vnf(k)*sp(k)
        enddo
        if (soma.ge.0.) then
	  teta1(i,j)=teta
	else
	  if (teta.ge.0.) then
	    teta1(i,j)=teta-pi
	  else
	    teta1(i,j)=pi+teta
	  endif
        endif
      endif
c
      return
      end
c----------end of first_rot------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine second_rot: 
c     2nd rotation (axe = sn)
c       called by : pbdir
c       call: none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine second_rot(i,j,beta,i4,v,f,teta2)
      use mod2
      use mod5
      implicit none
c
      integer :: i4,k,i,j
      real,dimension(3,3) :: v,beta,f
      real,dimension(200,2) :: teta2
      real :: rnum,den,rap,teta,som,h,tnvnf
      real,dimension(3) :: vnp2,vn1p,sp2,s3p,g,vnf
c
      rnum=beta(1,3)*beta(2,3)+r(i4)*beta(1,2)*beta(2,2)
      den=r(i4)*beta(2,2)*beta(3,2)+beta(2,3)*beta(3,3)
      if (den.eq.0.) then
        teta=pi/2.
      else
        rap=rnum/den
        teta=atan(rap)
      endif
      s3p(1)=sin(teta)
      s3p(2)=0.
      s3p(3)= cos(teta)
      sp2=matmul(v,s3p)
      vn1p(1)=cos(teta)
      vn1p(2)= 0.
      vn1p(3)=-sin(teta)
      vnp2=matmul(v,vn1p)
      g=matmul(f,vnp2)
      h=vnp2(1)*g(1)+vnp2(2)*g(2)+ vnp2(3)*g(3)
      do k=1,3
        vnf(k)=g(k)-h*vnp2(k)
      enddo
      tnvnf=sqrt(vnf(1)**2+vnf(2)**2+vnf(3)**2)
      if (tnvnf.lt.0.0000025) then
        teta2(i,j)=2.*pi
      else
        som=0.
        do k=1,3
	  vnf(k)=vnf(k)/tnvnf
	  som=som+vnf(k)*sp2(k)
        enddo
	if (som.ge.0.) then
	  teta2(i,j)=teta
	else
	teta2(i,j)=2.*pi
	endif
      endif
c
      return
      end
c----------end of second_rot------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine third_rot: 
c     3rd rotation (axe = slip vector)
c       called by : pbdir
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine third_rot(i,j,beta,i4,v,s,f,teta3)
      use mod2
      use mod5
      implicit none
c
      integer :: i4,k,i,j,k44
      real,dimension(3) :: s,vn3p,vnp3,g,vnf
      real,dimension(3,3) :: v,beta,f
      real,dimension(200,2) :: teta3
      real :: rnum,den,teta,som,h,tnvnf
      real :: tetac,po,tetaa,tetab
c
      k44=0
      rnum=r(i4)*(beta(1,2)**2-beta(2,2)**2)
     1	 +beta(1,3)**2-beta(2,3)**2
      if (rnum.eq.0.) then
        teta=pi/4.
        tetac=teta
      else
        den=r(i4)*beta(2,2)*beta(1,2)+beta(2,3)*beta(1,3)
        teta=0.5*atan(2.*den/rnum)
        tetac=teta
      endif
c
 62    vn3p(1)=cos(tetac)
      vn3p(2)=sin(tetac)
      vn3p(3)=0.
      vnp3=matmul(v,vn3p)
      g=matmul(f,vnp3)
      h=vnp3(1)*g(1)+vnp3(2)*g(2)+vnp3(3)*g(3)
      do k=1,3
        vnf(k)=g(k)-h*vnp3(k)
      enddo
      tnvnf=sqrt(vnf(1)**2+vnf(2)**2+vnf(3)**2)
      if (tnvnf.ge.0.0000025) then
        som=0.
        do k=1,3
	  vnf(k)=vnf(k)/tnvnf
          som=som+vnf(k)*s(k)
        enddo
        po=pi
        if (som.ge.0.95) goto 9
      endif
      if (k44.eq.0) goto 80
      if (k44.eq.1) goto 81
      if (k44.eq.2) goto 82
      if (k44.eq.3) goto 83
      if (k44.eq.4) goto 84
      if (k44.eq.5) goto 85
      if (k44.eq.6) goto 86
      if (k44.eq.7) goto 87
 80    if ((teta.ge.0.).and.(teta.lt.(po/4.))) goto 70
      if ((teta.lt.0.).and.(teta.gt.(-po/4.))) goto 71
 81    if ((teta.ge.0.).and.(teta.lt.(po/4.))) goto 72
      if ((teta.lt.0.).and.(teta.gt.(-po/4.))) goto 73
 82    if ((tetaa.ge.(-po/2.)).and.(tetaa.lt.(-po/4.))) goto 74
      if ((tetaa.gt.(po/4.)).and.(tetaa.lt.(po/2.))) goto 75
 83    if ((tetab.ge.(po/2.)).and.(tetab.lt.(3.*po/4.))) goto 76
      if ((tetab.gt.(-3.*po/4.)).and.(tetab.lt.(-po/2.))) goto 77
 84    if ((tetaa.ge.(-po)).and.(tetaa.lt.(-3.*po/4.))) goto 74
      if ((tetaa.gt.(3.*po/4.)).and.(tetaa.lt.po)) goto 75
 85    if ((tetab.ge.po).and.(tetab.lt.(5.*po/4.))) goto 76
      if ((tetab.gt.(-5.*po/4.)).and.(tetab.lt.(-po))) goto 77
 86    if ((tetaa.ge.(-3.*po/2.)).and.(tetaa.lt.(-5.*po/4.))) goto 74
      goto 75
 70    k44=k44+1
      tetaa=teta-po/2.
      tetac=tetaa
      goto 62
 71    k44=k44+1
      tetaa=teta+po/2.
      tetac=tetaa
      goto 62
 72    k44=k44+1
      tetab=teta+po/2.
      tetac=tetab
      goto 62
 73    k44=k44+1
      tetab=teta-po/2.
      tetac=tetab
      goto 62
 74    k44=k44+1
      tetaa=tetaa-po/2.
      tetac=tetaa
      goto 62
 75    k44=k44+1
      tetaa=tetaa+po/2.
      tetac=tetaa
      goto 62
 76    k44=k44+1
      tetab=tetab+po/2.
      tetac=tetab
      goto 62
 77    k44=k44+1
      tetab=tetab-po/2.
      tetac=tetab
      goto 62
 9     teta3(i,j)=tetac
      goto 8
 87    teta3(i,j)=2.*po
c
 8     continue
      return
      end
c----------end of third_rot------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine misfit : 
c     calculation of the global and reduced misfits: 
c     somo, somi + the number of compatibles planes: n1
c       called by : pbdir
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine misfit(i,i1,i2,i3,i4,teto,n1,somo,somi,val_rot)
      use mod1
      implicit none
c
      integer :: i
      real,dimension(200,2) :: teto
      real,dimension(200) :: amisf,amisfa,sigpno
      real :: somo,somi,aaa,bbb,ss
      integer,dimension(200,2) :: val_rot
      integer :: i1,i2,i3,i4
      integer,dimension(91,91,91,51) :: n1
      if (jklm.eq.1) then
c       no ponderation
        if (teto(i,1).le.teto(i,2)) then
          amisf(i)=teto(i,1)
          amisfa(i)=teto(i,1)
          sigpno(i)=sigpl(i,1)
          val_rot(i,1)= 10 + val_rot(i,1)
        else
	  amisf(i)=teto(i,2)
	  amisfa(i)=teto(i,2)
	  sigpno(i)=sigpl(i,2)
          val_rot(i,2)= 20 + val_rot(i,2)
	endif
      else
c       rough ponderation
        aaa=teto(i,1)/sigpl(i,1)
	bbb=teto(i,2)/sigpl(i,2)
	if (aaa.le.bbb) then
	  amisf(i)=aaa
	  amisfa(i)=teto(i,1)
	  sigpno(i)=sigpl(i,1)
          val_rot(i,1)= 10 + val_rot(i,1)
	else
	  amisf(i)=bbb
	  amisfa(i)=teto(i,2)
	  sigpno(i)=sigpl(i,2)
          val_rot(i,2)= 20 + val_rot(i,2)
	endif
      endif
c       
c       consistance treshold
c
      ss=sigmi+sigpno(i)
      if (amisfa(i).le.ss) then
        n1(i1,i2,i3,i4)=n1(i1,i2,i3,i4)+1
        somi=somi+amisf(i)
        somo=somo+amisf(i)
      else
        somo=somo+amisf(i)
      endif
      return
      end
c----------end of misfit------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine mini :
c     minimum between 3 angular values
c       called by : pbdir
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine mini(i,j,teta1,teta2,teta3,teti,val_rot)
      implicit none
c
      integer :: i,j
      real,dimension(200,2) :: teta1,teta2,teta3
      real :: teti
      integer,dimension(200,2) :: val_rot
c
      teti=abs(teta1(i,j))
      val_rot(i,j) = 1
      if (abs(teta2(i,j)).lt.teti) then
        teti=abs(teta2(i,j))
        val_rot(i,j) = 2
      endif
      if (abs(teta3(i,j)).lt.teti) then
        teti=abs(teta3(i,j))
        val_rot(i,j) = 3
      endif
c
      return
      end
c----------end of mini------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine minc : 
c     minimum between 3 values of angle with physical criterion 
c       called by : pbdir
c       call      : comme
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine minc(i,j,teta1,teta2,teta3,s,sn,vn,teti,df,pf,pif)
      implicit none
c
      integer :: i,j
      real,dimension(200,2) :: teta1,teta2,teta3,df,pf,pif
      real :: teti
      real,dimension(3) :: vn,sn,s,cs
c
      teti=abs(teta1(i,j))
      cs(1)=vn(1)
      cs(2)=vn(2)
      cs(3)=vn(3)
      if (abs(teta2(i,j)).lt.teti) then
        teti=abs(teta2(i,j))
        cs(1)=sn(1)
        cs(2)=sn(2)
        cs(3)=sn(3)
      endif
      if (abs(teta3(i,j)).lt.teti) then
        teti=abs(teta3(i,j))
        cs(1)=s(1)
        cs(2)=s(2)
        cs(3)=s(3)
      endif
      call comme(i,j,cs,s,vn,df,pf,pif,teti)
      return
      end
c----------end of minc------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine mina : 
c     Search for the tensor that have the minimum 
c     global misfit 
c       called by : princ. prog.
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine mina(amisfi,bma,j1,j2,j3,j4)
      use mod1
      implicit none
c
      real,dimension(91,91,91,51) :: amisfi
      real :: bma
      integer :: j1,j2,j3,j4,i1,i2,i3,i4
c
      bma=amisfi(1,1,1,1)
      j1=1
      j2=1
      j3=1
      j4=1
      do i1=1,l1
        do i2=1,l2
          do i3=1,l3
            do i4=1,l4
	      if (amisfi(i1,i2,i3,i4).lt.bma) then 
	        bma=amisfi(i1,i2,i3,i4)
	        j1=i1
	        j2=i2
	        j3=i3
	        j4=i4
	      endif
	    enddo
	  enddo
        enddo
      enddo
      return
      end
c----------end of mina------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine lim_conf : 
c     estimation of the limit values for the confidence 
c     limit domains
c       called by : princ. prog.
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine lim_conf(bma,vm50,vm90,vm95)
      use mod1
      use mod5
      implicit none
c
      real :: vm50,vm90,vm95,bma,vmoy1,sigest
c
      vm95=(1./(m-4))*bma *(1.96 *sqrt((pi/2.-1.)*m)+m)
      vm90=(1./(m-4))*bma *(1.645*sqrt((pi/2.-1.)*m)+m)
      vm50=(1./(m-4))*bma *(0.676*sqrt((pi/2.-1.)*m)+m)
      vmoy1=sqrt(2./pi)*(m-4)
      sigest=bma/vmoy1
      return
      end
c----------fin de lim_conf------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine selec_in_conf : 
c     writing of the stress tensor and of the 
c     confidence zones
c     in filen2 50% confidence zone
c     in filen3 90% confidence zone that does not belong 
c     to the 50% confidence zone
c     in filen4 95% confidence zone that does not belong 
c     to the 90% confidence zone
c     in filen9 90% confidence zone
c       called by : princ. prog.
c       call      : euler2map
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine selec_in_conf(cmisfi,vm50,vm90,vm95,it)
      use mod1
      use mod2
      use mod3
      use mod4
      implicit none
c
      real,dimension(91,91,91,51) :: cmisfi
      real :: vm50,vm90,vm95
      integer :: i1,i2,i3,i4,it
      real :: sig1d,sig1p,sig2d,sig2p,sig3d,sig3p
      real :: ang1,ang2,ang3,ang4
      character :: nit
      character(30) :: fich2, fich3,fich4,fich9
c
      if (it .eq. 1) then
        open (lk2,file=filen2)
        open (lk3,file=filen3)
        open (lk4,file=filen4)
        open (lk9,file=filen9)
      else
        write(nit,'(i1)')it
        write(*,*)nit,it
        fich2=trim(filen2) // nit
        fich3=trim(filen3) // nit
        fich4=trim(filen4) // nit
        fich9=trim(filen9) // nit
        open (lk2,file=fich2)
        open (lk3,file=fich3)
        open (lk4,file=fich4)
        open (lk9,file=fich9)
        write(*,*)fich2
      endif
      do i1=1,l1
	do i2=1,l2
	  do i3=1,l3
	    do i4=1,l4
	      if (cmisfi(i1,i2,i3,i4).lt.vm50) then
                call euler2map(i1,i2,i3,
     @              sig1d,sig1p,sig2d,sig2p,sig3d,sig3p)
		write(lk2,2004) sig1d,sig1p,sig2d,sig2p,sig3d,sig3p,r(i4)
	      else
	        if (cmisfi(i1,i2,i3,i4).lt.vm90) then
                  call euler2map(i1,i2,i3,
     @                sig1d,sig1p,sig2d,sig2p,sig3d,sig3p)
                  write(lk3,2004) sig1d,sig1p,sig2d,sig2p,sig3d,sig3p,
     @                r(i4)
		else
		  if (cmisfi(i1,i2,i3,i4).lt.vm95) then
                    call euler2map(i1,i2,i3,
     @                  sig1d,sig1p,sig2d,sig2p,sig3d,sig3p)
                    write(lk4,2004) sig1d,sig1p,sig2d,sig2p,
     @                  sig3d,sig3p,r(i4)
	          endif
		endif
	      endif
              if (cmisfi(i1,i2,i3,i4).lt.vm90) then
                ang1=psi1(i1)
                ang2=phi1(i2)
                ang3=tet1(i3)
                ang4=r(i4)
                write(lk9,2201) ang1,ang2,ang3,ang4
              endif
	    enddo
	  enddo
	enddo
      enddo
2004   format(1x,7(2x,f9.4))
2201   format(1x,4(2x,f9.4))
      close(lk2)
      close(lk3)
      close(lk4)
      close(lk9)
c
      return
      end
c----------end of selec_in_conf------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine min_comp : 
c     estimation of the best tensor compatible with 
c     m11 FM and determination of the corresponding 
c     misfit and of the compatible nodal planes
c       called by : prog. princ. 
c       call      : euler2map, pbdir, choix
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine min_comp(m11,n1,bmisfi,bmi,ii1,ii2,ii3,ii4,
     @     k444,k1,k2)
      use mod1
      use mod2
      use mod4
      implicit none
c
      integer,dimension(91,91,91,51) :: n1
      real :: bmi
      integer:: ii1,ii2,ii3,ii4,m11,i1,i2,i3,i4,k444,mno
      integer,dimension(200) :: k1,k2
      real :: sig1d,sig1p,sig2d,sig2p,sig3d,sig3p
      real,dimension(91,91,91,51) :: amisfi,bmisfi
      real,dimension(200,2) :: teto,df,pf,pif
      integer,dimension(200,2) :: val_rot
c
      k444=0
      do i1=1,l1
        do i2=1,l2
          do i3=1,l3
            do i4=1,l4
              if (n1(i1,i2,i3,i4).eq.m11) then
                k444=k444+1
                if (k444.eq.1) then
                  bmi=bmisfi(i1,i2,i3,i4)
                  ii1=i1
                  ii2=i2
                  ii3=i3
                  ii4=i4
                elseif (bmisfi(i1,i2,i3,i4).lt.bmi) then
                  bmi=bmisfi(i1,i2,i3,i4)
                  ii1=i1
                  ii2=i2
                  ii3=i3
                  ii4=i4
                endif
                call euler2map(i1,i2,i3,sig1d,sig1p,sig2d,
     @              sig2p,sig3d,sig3p)
                write(lk8,*) '# ',m11,i1,i2,i3,i4
                write(lk8,705) sig1d,sig1p,sig2d,sig2p,sig3d,sig3p,r(i4)
c     for the considered tensor, teto is reestimated and we search for the 
c     compatibles planes
                mno=0
                call pbdir(i1,i2,i3,i4,mno,amisfi,bmisfi,
     @              teto,n1,val_rot,df,pf,pif)
                call choix(i1,i2,i3,i4,teto,k1,k2)
              endif
            enddo
          enddo
        enddo
      enddo
 705   format(1x,6(f7.2,1x),f4.2)
      return
      end
c----------end of min_comp------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine selec_val_rot : 
c     selection of the nodal plane with the minimum 
c     misfit as fault plane
c       called by : princ. prog.
c       call      : pbdir
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine selec_val_rot(j1,j2,j3,j4,teto,plan,val_rot)
      use mod1
      use mod5 
      implicit none
c
      integer,dimension(200,2) ::  val_rot
      integer :: j1,j2,j3,j4,i,mno
      integer,dimension(200) :: plan
      real,dimension(91,91,91,51) :: amisfi,bmisfi
      integer,dimension(91,91,91,51) :: n1
      real,dimension(200,2) :: df,pf,pif,teto
      mno=0
      call pbdir(j1,j2,j3,j4,mno,amisfi,bmisfi,teto,
     @    n1,val_rot,df,pf,pif)
      do i=1,m
        if (val_rot(i,1).gt.10.and.val_rot(i,1).lt.20) then
          val_rot(i,1) = val_rot(i,1) - 10
          plan(i) = 1
        endif
        if (val_rot(i,2).gt.20) then
          val_rot(i,2) = val_rot(i,2) - 20
          plan(i) = 2
        endif
      enddo
      return
      end
c----------end of selec_val_rot------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c       subroutine comme :
c     Turned planes caracteristics
c     no horizontal planes as input
c     if after the rotation there is an horizontal plane,
c     it is turned of teti-1 deg.
c     turned plane: normal vestor oriented upward
c     when the plane is vertical, the normal vector is the
c     transformed of vn by rotation
c
c       called by : minc
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine comme(i,j,cs,s,vn,df_mf,pf_mf,pif_mf,teti)
c
      use mod5
      implicit none
c
      integer :: i,j,ii
      real,dimension(3) :: vn,cs,s,s1,pla,plu,tnon,u22,pl2
      real :: teti,tetu,ct1,am,bm,cm,tnop,d33,pif1,d44,prod
      real,dimension(200,2) :: df_mf,pf_mf,pif_mf
      real,dimension(3,3) ::  tmatr(3,3)
      real :: br,br9,br10,tnol2,prp,a15,tnpi,pf,df,pif,pf1,df1
c
c     initialisation
c
      tetu = teti
      ct1 = pi/180.
c
139    am = cos(tetu)
      if (am.ge.0.99999) am=1.
      if (am.le.-0.99999) am=-1.
      if (abs(am).le.0.00001) am=0.
      bm = 1.-am
      cm=sin(tetu)
      if (cm.ge.0.99999) cm=1.
      if (cm.le.-0.99999) cm=-1.
      if (abs(cm).le.0.00001) cm=0.
      tmatr(1,1)=am+bm*cs(1)**2
      tmatr(1,2)=bm*cs(1)*cs(2)-cm*cs(3)
      tmatr(1,3)=bm*cs(1)*cs(3)+cm*cs(2)
      tmatr(2,1)=bm*cs(2)*cs(1)+cm*cs(3)
      tmatr(2,2)=am+bm*cs(2)**2
      tmatr(2,3)=bm*cs(2)*cs(3)-cm*cs(1)
      tmatr(3,1)=bm*cs(3)*cs(1)-cm*cs(2)
      tmatr(3,2)=bm*cs(3)*cs(2)+cm*cs(1)
      tmatr(3,3)=am+bm*cs(3)**2
c
c     transformation of the vectors vn and s
c
      s1=matmul(tmatr,s)
c     calculation of the normal to the turned plane
c     after rotation of vn
      pla=matmul(tmatr,vn)
      do ii=1,3
        if(pla(ii).ge.0.99999) pla(ii)=1.
        if(abs(pla(ii)).le.0.00001) pla(ii)=0.
        if (pla(ii).le.-0.99999) pla(ii)=-1.
      enddo
      if (pla(3).gt.0.) then
        do ii=1,3
          plu(ii)=-pla(ii)
        enddo
      else
        do ii=1,3
          plu(ii)=pla(ii)
        enddo
      endif
cc
c     characteristics of the turned plane
cc
c     horizontal of the turned plane
c
      tnop=sqrt(plu(1)**2+plu(2)**2+plu(3)**2)
      tnon(1)=plu(1)/tnop
      tnon(2)=plu(2)/tnop
      tnon(3)=plu(3)/tnop
      d33=sqrt(tnon(1)**2+tnon(2)**2)
      if (d33.ne.0.) goto 138
      tetu=tetu-1.*pi/180.
      goto 139
138    u22(1)=tnon(2)/d33
      u22(2)=-tnon(1)/d33
      u22(3)=0.
c
c     l.p.g.p. of the turned plane
c
      if ((u22(1).eq.0.).and.(tnon(3).ne.0.)) goto 141
      if (tnon(3).eq.0.) goto 176
      br=(1./tnon(3))*(tnon(1)*u22(2)/u22(1)-tnon(2))
      br9=-u22(2)/u22(1)
      if (br.lt.0.) goto 143
      pl2(1)=br9
      pl2(2)=1.
      pl2(3)=br
      goto 144
143    pl2(1)=-br9
      pl2(2)=-1.
      pl2(3)=-br
      goto 144
176    pl2(1)=0.
      pl2(2)=0.
      pl2(3)=1.
      goto 144
141    br10=-tnon(1)/tnon(3)
      pl2(2)=0.
      if (br10.lt.0.) goto 145
      pl2(1)=1
      pl2(3)=br10
      goto 144
145    pl2(1)=-1.
      pl2(3)=-br10
c
c     dip of the turned plane
c
144    tnol2=sqrt(pl2(1)**2+pl2(2)**2+pl2(3)**2)
      prp=pl2(3)
      a15=prp/tnol2
      if (a15.gt.1.) a15=1.
      if (a15.lt.-1.) a15=-1.
      tnpi=acos(a15)
      pf=pi/2.-tnpi
c
c     azimut of the turned plane
c
      if (u22(1).eq.0.) goto 630
      d44=u22(1)
      if (u22(2).gt.0.) goto 632
      if (u22(2).lt.0.) goto 633
      if (u22(2).eq.0.) goto 620
632    df=acos(d44)
      goto 622
633    df=2.*pi-acos(d44)
      goto 622
620    if (pl2(2).ge.0.) goto 627
      df=pi
      goto 622
627    df=0.
      goto 622
630    if (pl2(1).le.0.) goto 629
      df=3.*pi/2.
      goto 622
629    df=pi/2.
c
c     pitch
c
622    prod=u22(1)*s1(1)+u22(2)*s1(2)
      if (abs(s1(3)).lt.0.00001) goto 623
      if (s1(3).le.0.) goto 624
      pif=2.*pi-acos(prod)
      goto 625
624    pif=acos(prod)
      goto 625
623    if (prod.gt.0.99999) goto 628
      pif=pi
      goto 625
628    pif=0.
c
625    pf1=pf/ct1
      df1=df/ct1
      pif1=pif/ct1
      df_mf(i,j) = df1
      pf_mf(i,j) = pf1
      pif_mf(i,j) = pif1
c
      return
      end
c----------end of comme------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine plan_tourne : 
c     calculation of the new orientations of the nodal 
c     plane for a stress tensor of index (j1,j2,j3,j4)
c    
c       called by : prog. princ.
c       call      : pbdir
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine plan_tourne(j1,j2,j3,j4,df,pf,pif)
      implicit none
c
      integer,dimension(200,2) :: val_rot
      integer ::  j1,j2,j3,j4,mno
      real,dimension(91,91,91,51) :: amisfi,bmisfi
      integer,dimension(91,91,91,51) :: n1
      real,dimension(200,2) :: teto,df,pf,pif
c      
      mno=1
      call pbdir(j1,j2,j3,j4,mno,amisfi,bmisfi,teto,
     @     n1,val_rot,df,pf,pif)
c
      return
      end
c----------end of plan_tourne------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c       subroutine write_data_recal :
c       Writing of the input data and of the recalulated
c       data
c         called by : prog princ
c         call      : zero_180,computed_strike1,
c         computed_dip1,computed_rake1
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine write_data_recal(tetu,plan,df_mf,pf_mf,pif_mf)
      use mod1
      use mod3
      use mod4
      use mod5
      implicit none
c
      real,dimension(200,2) :: df_mf,pf_mf,pif_mf,tetu
      real :: tet_rotmf,df_in,pf_in,pif_in,zpif_mf,df_in2,pf_in2,pif_in2
      real :: st1,st2,dp1,dp2,rk1,rk2,tet_rej
      integer :: i
      integer,dimension(200) :: plan
c
      do i=1,m
        zpif_mf = pif_mf(i,1)
        call zero_180(zpif_mf)
        pif_mf(i,1) = zpif_mf
        zpif_mf = pif_mf(i,2)
        call zero_180(zpif_mf)
        pif_mf(i,2) = zpif_mf
        st1=df_mf(i,1)
        dp1=pf_mf(i,1)
        rk1=pif_mf(i,1)
        st2=df_mf(i,2)
        dp2=pf_mf(i,2)
        rk2=pif_mf(i,2)
        if (tetu(i,1).lt.tetu(i,2)) then
          tet_rotmf = tetu(i,1)
          tet_rej = tetu(i,2)
          call computed_strike1(st1,dp1,rk1,st2)
          call computed_dip1(dp1,rk1,dp2)
          call computed_rake1(dp1,rk1,rk2)
        else
          tet_rotmf = tetu(i,2)
          tet_rej = tetu(i,1)
          call computed_strike1(st2,dp2,rk2,st1)
          call computed_dip1(dp2,rk2,dp1)
          call computed_rake1(dp2,rk2,rk1)
        endif
        df_mf(i,1)=st1
        pf_mf(i,1)=dp1
        pif_mf(i,1)=rk1
        df_mf(i,2)=st2
        pf_mf(i,2)=dp2
        pif_mf(i,2)=rk2
        df_in = x(i,1,1)*180./pi
        pf_in = x(i,1,2)*180./pi
        pif_in = x(i,1,3)*180./pi
        df_in2 = x(i,2,1)*180./pi
        pf_in2 = x(i,2,2)*180./pi
        pif_in2 = x(i,2,3)*180./pi
        write(lk7,1038) i,df_in,pf_in,pif_in,
     @          df_mf(i,1),pf_mf(i,1),pif_mf(i,1),
     @          df_in2,pf_in2,pif_in2,
     @          df_mf(i,2),pf_mf(i,2),pif_mf(i,2),
     @          tet_rotmf * 180./pi,tet_rej * 180./pi,plan(i)
      enddo
 1038  format(1x,i2,1x,12(f6.1,1x),2(f9.3,1x),i1)
      return
      end
c----------end of write_data_recal--------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c       subroutine  : computed_strike1
c       Estimation of the strike of the 2nd nodal plane
c       when str1, dip1, rake1 are known
c       called by : write_data_recal
c       call      : zero_360
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine computed_strike1(strs1,dips1,rakes1,strs2)
      use mod5
      implicit none
      real :: strs1,dips1,rakes1,strs2
      double precision :: str1,dip1,rake1,str2,cd1,cp2,sp2
      double precision :: ss,cs,sr,cr,d2r,epsil,r2d
      integer :: am
c
      str1=strs1
      dip1=dips1
      rake1=rakes1
      d2r = pi/180.
      r2d = 180./pi
      epsil = 0.0001
c
      if (abs(rake1).lt.0.000001) then
        am = +1
      else
        am = nint(rake1/abs(rake1))
      endif
      cd1 = dcos(dip1*d2r)
      sr = dsin(rake1*d2r)
      cr = dcos(rake1*d2r)
      ss = dsin(str1*d2r)
      cs = dcos(str1*d2r)
c
      if (cd1.lt.epsil.and.abs(cr).lt.epsil) then
        str2 = str1
      else
        sp2 = -am * (cr * cs + sr * ss * cd1)
        cp2 =  am * (ss * cr - sr * cs * cd1)
        str2 = datan2(sp2, cp2)
        str2 = str2 * r2d
        call zero_360(str2)
        strs2=str2
      endif
      return
      end
c----------end of computed_strike1------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c       subroutine  : zero_360
c       Put an angle between 0° and 360°
c       called by : computed_strike1
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine zero_360(str)
      implicit none
      double precision :: str
c
      if (str.ge.360.) then
        str = str - 360.
      elseif (str.lt.0.) then
        str = str + 360.
      endif
      return
      end
c----------end of zero_360------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c       subroutine  : zero_180
c      Return an angle between [-180,180]
c       called by : computed_strike1
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine zero_180(str)
      implicit none
      real :: str
c
      if (str.gt.180.) then
        str = str - 360.
      endif
      return
      end
c----------end of zero_180------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c       subroutine  : computed_dip1
c       Estimation of the dip of the 2nd nodal plane
c       when dip1, rake1 are known
c       called by : write_data_recal
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine computed_dip1(dips1,rakes1,dips2)
c
      use mod5
      implicit none
      real :: dips1,rakes1,dips2
      double precision :: dip1,rake1,dip2,d2r,r2d
      integer :: am
c
      dip1 = dips1
      rake1 = rakes1
      d2r = pi/180.
      r2d = 180./pi
c
      if (abs(rake1).lt.0.000001) then
         am = +1
      else
         am = nint(rake1/abs(rake1))
      endif
      dip2 = acos(am * dsin(rake1* d2r) * dsin(dip1 * d2r)) * r2d
      dips2 = dip2
c
      return
      end
c----------end of computed_dip1------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c       subroutine  : computed_rake1
c       Estimation of the rake of the 2nd nodal plane
c       when dip1, rake1 are known
c       called by : write_data_recal
c       call      : computed_strike1, computed_dip1
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine computed_rake1(dips1,rakes1,rakes2)
c
      use mod5
      implicit none
      real :: dips1,rakes1,rakes2
      double precision :: dip1,rake1,rake2,d2r,epsil,r2d
      integer :: am
c
      dip1 = dips1
      rake1 = rakes1
c
      d2r = pi/180.
      r2d = 180./pi
      epsil = 0.0001
      if (abs(rake1).lt.0.000001) then
        am = +1
      else
        am = nint(rake1/abs(rake1))
      endif
c
      if (abs(90.-dip1).lt.0.000001.and.abs(90.-rake1).lt.0.000001) then
        rake2 = 0.
      else
        rake2 = datan2(am * dcos(dip1*d2r), - dsin(dip1*d2r) * 
     @        dcos(rake1 * d2r)) * r2d
      endif
      rakes2 = rake2
      return
      end
c----------end of computed_rake1------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine pl_non_cons : 
c     to find the nodal planes inconsistents with the
c     estimated stress tensor
c       called by : prog. princ.
c       call      : pbdir
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine pl_non_cons(j1,j2,j3,j4)
      use mod1
      use mod4
      implicit none
c
      integer :: j1,j2,j3,j4,mno,i
      integer,dimension(91,91,91,51) :: n1
      integer,dimension(200,2) :: val_rot
      real,dimension(91,91,91,51) :: amisfi,bmisfi
      real,dimension(200,2) :: teto,df,pf,pif
      real,dimension(200) :: sigpno
      real :: aaa,bbb
c
      mno=0
      call pbdir(j1,j2,j3,j4,mno,amisfi,bmisfi,
     @     teto,n1,val_rot,df,pf,pif)
      do i=1,m
        if (jklm.eq.2) then
          aaa=teto(i,1)/sigpl(i,1)
          bbb=teto(i,2)/sigpl(i,2)
          if (aaa.le.bbb) then
            sigpno(i)=sigpl(i,1)
            if (teto(i,1).gt.(sigmi+sigpno(i))) then
              write(lk5,81) j1,j2,j3,j4,i
            endif
          else
            sigpno(i)=sigpl(i,2)
            if (teto(i,2).gt.(sigmi+sigpno(i))) then
              write(lk5,80) j1,j2,j3,j4,i
            endif
          endif
        else
          if (teto(i,1).le.teto(i,2)) then
            sigpno(i)=sigpl(i,1)
            if (teto(i,1).gt.(sigmi+sigpno(i))) then
              write(lk5,81) j1,j2,j3,j4,i
            endif
          else
            sigpno(i)=sigpl(i,2)
            if (teto(i,2).gt.(sigmi+sigpno(i))) then
              write(lk5,80) j1,j2,j3,j4,i
            endif
          endif
        endif
      enddo
 80    format('(',i3,i3,i3,i3,') not consist with plane 2 no',i3)
 81    format('(',i3,i3,i3,i3,') not consist with plane 1 no',i3)
      return
      end
c----------end of pl_non_cons------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine input1 : 
c     input of the data and calculation of the second
c     nodal plane parameters
c       called by : prog. princ.
c       call      : computed_strike1, computed_dip1,
c       computed_rake1
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine input1
      use mod1
      use mod2
      use mod3
      use mod4
      use mod5
      implicit none
c
      integer :: i,j,k
      real :: ct1,df_in,pf_in,pif_in,df_in2,pf_in2,pif_in2
      character (1) :: numero
      character (2) :: conl      
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     reading of the data file and restrictions on the
c     grid search
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      write(*,*) 'restriction on a principal stress?'
      write(*,*) '(s1 -> 1 ; s3 -> 3 ; no -> 0)'
      read(*,*) restr
      if (restr>=1) then
        write( numero, '(i1)' ) restr
        conl='s' // numero
        write(*,*) 'dipping from the vertical of ', conl, '?'
        read(*,*) pd3
        write(*,*) 'min azimut of ', conl, ' ?'
        read(*,*) az3mi
        write(*,*) 'max azimut of', conl,' ?'
        read(*,*) az3ma
      endif
      write(*,*) 'impose 1 vertical stress (dipping of less than 20°)?' 
      write(*,*) '(yes -> 1 ; no -> 0)'
      read(*,*) vv
      write(*,*) 'input data filename'
      read(*,10) filen1
      filen5='output_' // filen1
      filen2='sol50_' // filen1
      filen3='sol90_' // filen1
      filen4='sol95_' // filen1
      filen6='mtens_' // filen1
      filen7='mfoy_' // filen1
      filen8='tens_' // filen1
      filen9='eul_' // filen1
      print *, "output files"
      print *, filen2,filen3,filen4,filen6,filen7,filen8,filen9
   10  format(a70)
      open(lk1,file=filen1)
      read(lk1,*) m,N,
	1    ((x(i,1,k),k=1,3),i=1,m),
	2    ((sigpl(i,j),j=1,2),i=1,m),jklm,sigmi,
	3    l1,l2,l3,l4,
	4    (psi1(i),i=1,l1),(phi1(i),i=1,l2),(tet1(i),i=1,l3),
     @        (r(i),i=1,l4)
      close(lk1)
cccccccccccccccccccccccccccccccccccccccccccccccccccc
c     initialisations : 2nd nodal plane calculation
cccccccccccccccccccccccccccccccccccccccccccccccccccc
      do i=1,m
        df_in = x(i,1,1)
        pf_in = x(i,1,2)
        pif_in = x(i,1,3)
        call zero_180(pif_in)
        call computed_strike1(df_in,pf_in,pif_in,df_in2)
        call computed_dip1(pf_in,pif_in,pf_in2)
        call computed_rake1(pf_in,pif_in,pif_in2)
        x(i,2,1) = df_in2
        x(i,2,2) = pf_in2
        x(i,2,3) = pif_in2
      enddo
cccccccccccccccccccccccccccccccccccccccccccccccccccc
c     initialisations : degrees -> radians
cccccccccccccccccccccccccccccccccccccccccccccccccccc
      ct1=pi/180.
      sigmi=sigmi*ct1
      do i=1,m
        do j=1,2
          sigpl(i,j)=sigpl(i,j)*ct1
          do k=1,3
            x(i,j,k)=x(i,j,k)*ct1
          enddo
        enddo
      enddo
c
       return
       end
c----------end of input1------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine choix : 
c     selection of the planes non consistents with a
c     determined tensor
c       called by : min_comp
c       call      : aucun
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine choix(i1,i2,i3,i4,teto,k1,k2)
      use mod1
      use mod3
      use mod4
      implicit none
c
      integer :: i1,i2,i3,i4,i
      real,dimension(200,2) :: teto
      real,dimension(200) :: sigpno
      integer,dimension(200) :: k1,k2
      real :: aaa,bbb
c
      do i=1,m
        if (jklm.eq.2) then
          aaa=teto(i,1)/sigpl(i,1)
          bbb=teto(i,2)/sigpl(i,2)
          if (aaa.le.bbb) then
            sigpno(i)=sigpl(i,1)
            if (teto(i,1).le.(sigmi+sigpno(i))) then
              k1(i)=k1(i)+1
            else
              write(lk8,81) i1,i2,i3,i4,i
            endif
          else
            sigpno(i)=sigpl(i,2)
            if (teto(i,2).le.(sigmi+sigpno(i))) then
              k2(i)=k2(i)+1
            else
              write(lk8,80) i1,i2,i3,i4,i
            endif
          endif
        else
          if (teto(i,1).le.teto(i,2)) then
            sigpno(i)=sigpl(i,1)
            if (teto(i,1).le.(sigmi+sigpno(i))) then
              k1(i)=k1(i)+1
            else
              write(lk8,81) i1,i2,i3,i4,i
            endif
          else
            sigpno(i)=sigpl(i,2)
            if (teto(i,2).le.(sigmi+sigpno(i))) then
              k2(i)=k2(i)+1
            else
              write(lk8,80) i1,i2,i3,i4,i
            endif
          endif
        endif
      enddo
 80    format('(',i3,i3,i3,i3,') pas consist avec plan 2 no',i3)
 81    format('(',i3,i3,i3,i3,') pas consist avec plan 1 no',i3)
      return 
      end
c----------end of choix------------------------------
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine euler2map : 
c     Calculation of the azimuths and dips (here, angle/vertical)
c     of sig1, sig2, sig3 from the Euler angles.
c       called by : prog. princ.,selec_in_conf,min_comp
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine euler2map(l1,l2,l3,sig1d,sig1p,sig2d,sig2p,sig3d,sig3p)
      use mod2
      use mod5
      implicit none
c
      integer :: l1,l2,l3
      real :: sig1d,sig1p,sig2d,sig2p,sig3d,sig3p
c     
c Sigma1
c
      if (phi1(l2).le.90) then
         sig1d = psi1(l1) + 180
         sig1p = 90 - phi1(l2)
      else
         sig1d = psi1(l1)
         sig1p = phi1(l2) - 90
      endif
      if (sig1d.ge.360) then
         sig1d = sig1d - 360
      endif
      if (sig1p.ge.360) then
         sig1p = sig1p - 360
      endif
c     
c Sigma2
c
      if (phi1(l2).le.90) then
         if (phi1(l2).eq.90) then
            sig2d = psi1(l1) + 90 - tet1(l3)
         else
            if (tet1(l3).le.90) then
               if (tet1(l3).eq.90) then
                  sig2d = psi1(l1)
               else
                  sig2d = psi1(l1) + 90 - atan(sin(phi1(l2)*pi/180)
     @                 *tan(tet1(l3)*pi/180))*180/pi
               endif
            else
               sig2d = psi1(l1) + 90 - atan(sin(phi1(l2)*pi/180)
     @              *tan(tet1(l3)*pi/180))*180/pi + 180
            endif
         endif
      else
         if (tet1(l3).le.90) then
            if (tet1(l3).eq.90) then
               sig2d = psi1(l1) + 180
            else
               sig2d = psi1(l1) + 90 - atan(sin(phi1(l2)*pi/180)
     @              *tan(tet1(l3)*pi/180))*180/pi + 180
            endif
         else
            sig2d = psi1(l1) + 90 - atan(sin(phi1(l2)*pi/180)
     @           *tan(tet1(l3)*pi/180))*180/pi
         endif
      endif
      sig2p = 90 - abs(asin(cos(phi1(l2)*pi/180)
     @*sin(tet1(l3)*pi/180))*180/pi)
      if (sig2d.ge.360) then
         sig2d = sig2d - 360
      endif
      if (sig2p.ge.360) then
         sig2p = sig2p - 360
      endif
c     
c Sigma3
c
      if (phi1(l2).le.90) then
         if (phi1(l2).eq.90) then
            sig3d = psi1(l1) - tet1(l3)
         else
            if (tet1(l3).eq.90) then
               sig3d = psi1(l1) - 90
            endif
            if ((tet1(l3).eq.0).or.(tet1(l3).eq.180)) then
               sig3d = psi1(l1)
            endif
            if ((tet1(l3).lt.90).and.(tet1(l3).ne.0)) then
               sig3d = psi1(l1) - 90 + atan(sin(phi1(l2)*pi/180)
     @              /tan(tet1(l3)*pi/180))*180/pi
            else
               if ((tet1(l3).gt.90).and.(tet1(l3).ne.180)) then
                  sig3d = psi1(l1) - 90 + atan(sin(phi1(l2)*pi/180)
     @                 /tan(tet1(l3)*pi/180))*180/pi + 180
               endif
            endif
         endif
      else
         if (tet1(l3).eq.90) then
            sig3d = psi1(l1) - 90
         endif
         if ((tet1(l3).eq.0).or.(tet1(l3).eq.180)) then
            sig3d = psi1(l1) + 180
         endif
         if ((tet1(l3).lt.90).and.(tet1(l3).ne.0)) then
            sig3d = psi1(l1) - 90 + atan(sin(phi1(l2)*pi/180)
     @           /tan(tet1(l3)*pi/180))*180/pi + 180
         else
            if ((tet1(l3).gt.90).and.(tet1(l3).ne.180)) then
               sig3d = psi1(l1) - 90 + atan(sin(phi1(l2)*pi/180)
     @              /tan(tet1(l3)*pi/180))*180/pi
            endif
         endif
      endif
c
      sig3p = 90 - abs(asin(cos(phi1(l2)*pi/180)
     @     *cos(tet1(l3)*pi/180))*180/pi)
      if (sig3d.ge.360) then
         sig3d = sig3d - 360
      endif
      if (sig3p.ge.360) then
         sig3p = sig3p - 360
      endif
c
      return
      end
c----------end of euler2map------------------------------
