cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c----- Estimation of the uncertainty domain from 200 random selection of FM -------c
c
c general least squares procedure with the output of the approximate method 
c (Meca2tensb.f) as an initial solution
ccc
c   see Julien and Cornet, 1987 (Annales Geophysicae 5B) for more explanations
c
c   1-estimation of the function f(x)=sTn-[(Tn)^2-(nTn)^2]^1/2 for every FM (f(x)=0)
c   2-residue estimations, FOS=sqrt[sum(f^2)]
c   3-estimation of the partial derivatives of F at point x
c   4-estimation of x(k+1)=x0+C0.F'(k)(F(k).C0.F'(k))^(-1)*[F(k)(x(k)-x0)-f(x(k))]
c       ' means transpose matrix
c   5-if FO(i)-FO(i-1)<10^(-7) stop the iteration
c   6-estimation of the a posteriori covariance matrix
ccc
c   input parameters: name of an input file (XXX); 
c   input file format: cf input_pfml2.m
c   output files:
c     XXX.check: description of the results of the inversion step by step
c                 a posteriori covariance matrix and recalculed FM
c     XXX.outY: best stress tensor (3 euler angles + R)
C
C
c     DO NOT INTRODUCE A NULL VARIANCE IN THE A PRIORI COVARIANCE MATRIX
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      module mod1
      implicit none
      integer :: LLL=11,IU=12,IOUV=17
      SAVE
      end module mod1
c
      module mod2
      implicit none
      integer, parameter :: NDMAX=200
      integer, parameter :: NUMAX=3*NDMAX+4
      integer :: M,MU
      SAVE
      end module mod2
ccccc
      program P22
      use mod1
      use mod2
      implicit none
      character (30) :: filen1,filen2,filen3,filen
      integer :: I,J,L,K,i1,i2,i3,IJ
      double precision :: PI,AS,BS,FOS,FOSA
      double precision,dimension(NDMAX,3) :: XU,X,V,S,XF
      double precision,dimension(NDMAX,1) :: FO
      double precision,dimension(3,NDMAX) :: XT,XFT,G
      double precision,dimension(NUMAX,NUMAX) :: SIGU,SSIG,SIG,CP,DFO
      double precision,dimension(3,1) :: PAU
      double precision,dimension(NUMAX,1) :: PA,PARD,PAR
      double precision,dimension(3,3) :: B,F
c
      PI=3.1415926536d0
C
C     READING THE NAME OF THE INPUT FOLDER
C
      write(*,*) 'input folder'
      read(*,10) filen
   10  format(a70)
      i1=index(filen,' ')-1
      filen2= filen(1:i1) // '/check'
      filen3=filen(1:i1) // '/outten'
      OPEN(IU,FILE=filen2)
      OPEN(IOUV,FILE=filen3)
      filen1=filen(1:i1) // '/err000'
      i2=i1+5
      i3=i2+2
c loop on the name of the input file
      DO 77 IJ=1,999
      FOS=0.0d0
      write(filen1(i2:i3),'(i3.3)') IJ
      OPEN(LLL,FILE=filen1)
      READ(LLL,*) M,MU,
     $ ((XU(I,K),K=1,3),I=1,M),
     $ (SIGU(I,I),I=1,MU),
     $ (PAU(I,1),I=1,3),PA(4,1)
      CLOSE(LLL)
      WRITE(IU,*) '---------FILE N° ',IJ
C     INITIALIZATION FOR THE PARAMETERS
      DO I=1,MU
        DO J=1,MU
          SIG(I,J)=0.0d0
          SSIG(I,J)=0.0d0
        ENDDO
      ENDDO
      DO J=1,3
        SIG(J,J)=PI*SIGU(J,J)/180.0d0
        SSIG(J,J)=1./SIG(J,J)
        PA(J,1)=PI*PAU(J,1)/180.0d0
        PAR(J,1)=PA(J,1)
      ENDDO
      PAR(4,1)=PA(4,1)
      SIG(4,4)=SIGU(4,4)
      SSIG(4,4)=1./SIG(4,4)
C     INITIALIZATION FOR THE DATA
      K=1
      DO I=1,M
        DO J=1,3
          X(I,J)=PI*XU(I,J)/180.0d0
          XT(J,I)=X(I,J)
          PA(K+4,1)=X(I,J)
          K=K+1
        ENDDO
      ENDDO
      DO J=5,MU
        SIG(J,J)=PI*SIGU(J,J)/180.0d0
        PAR(J,1)=PA(J,1)
        SSIG(J,J)=1./SIG(J,J)
      ENDDO
C
C
C     END OF INITIALIZATION
C
C     PRINCIPAL PROGRAM
C
      L=0
c     calculation of the normal to the plane V for every MF
c     calculation of the slip on the plane S for every MF
4     do I=1,M
        V(I,1)=-sin(X(I,1))*sin(X(I,2))
        V(I,2)=cos(X(I,1))*sin(X(I,2))
        V(I,3)=-cos(X(I,2))
        S(I,1)=cos(X(I,1))*cos(X(I,3))+
     $sin(X(I,1))*sin(X(I,3))*cos(X(I,2))
        AS=sin(X(I,1))*cos(X(I,3))
        BS=cos(X(I,1))*sin(X(I,3))*cos(X(I,2))
        S(I,2)=AS-BS
        S(I,3)=-sin(X(I,2))*sin(X(I,3))
      enddo
C
      CALL PBDIR(PAR,V,S,FO,B,G,F)
      FOSA=FOS
      CALL TEST(FO,FOS)
      DO J=1,MU
        if (J .eq. 4)then
          PARD(4,1)=PAR(4,1)
        else
          PARD(J,1)=PAR(J,1)*180./PI
        endif
      ENDDO
      WRITE(IU,15) L,PARD(1,1),PARD(2,1),PARD(3,1),PARD(4,1)
15    FORMAT('ITERATION NB = ',I3,' PSI=',F5.1,' PHI=',F5.1,
     $' TET=',F5.1,' R=',F4.2)
c    if |FO(i)-FO(i-1)|<10^(-7) stop the iterative process
      IF (ABS(FOS-FOSA).LE.0.0000001) GOTO 14
      L=L+1
      IF (L.EQ.51) GO TO 20
c    estimation of the partial derivatives of f
      CALL DERIV(PAR,B,V,S,G,F,X,DFO)
c    estimation of x(k+1)
      CALL ITER(DFO,FO,PA,PAR,X,SIG)
      GO TO 4
14    WRITE(IOUV,144) PARD(1,1),PARD(2,1),PARD(3,1),PARD(4,1)
144   FORMAT(F15.8,2X,F15.8,2X,F15.8,2X,F10.8)
      CALL CRITER(PAR,PA,SSIG)
      CALL DERIV(PAR,B,V,S,G,F,X,DFO)
c    estimation of the covariance matrix
      CALL POSTMA(DFO,SIG,CP)
      WRITE(IU,246)
246   FORMAT(/'A POSTERIORI COVARIANCE MATRIX:')
      WRITE(IU,18)((CP(I,J),J=1,4),I=1,4)
18    FORMAT(4 D15.8)
      K=1
      DO I=1,M
        DO J=1,3
          XF(I,J)=PARD(K+4,1)
          K=K+1
        ENDDO
      ENDDO
      WRITE(IU,247)
247   FORMAT(/'RECALCULATED DATA:')
      WRITE(IU,219)((XF(I,J),J=1,3),I=1,M)
219   FORMAT(3F7.2)
20    WRITE(IU,21)
21    FORMAT('PROGRAM STOPPED AT THE 50th ITERATION')
77    CONTINUE
      CLOSE(IU)
      CLOSE(IOUV)
      STOP
      END
C----------end of MAIN PROG------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine PBDIR : 
c     Calculation of the stress tensor in the
c     geographical system of coordinates and estimation
c     of f=f(x)=sTn-[(Tn)^2-(nTn)^2]^1/2
c       called by : main program
c       call      : PMAT
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      SUBROUTINE PBDIR(PAR,V,S,FO,B,G,F)
      use mod2
      IMPLICIT NONE
      double precision, dimension(3,3) :: BU,BV,BW,T,C,B
      double precision, dimension(3,3) :: BT,E,F
      integer :: I,J
      double precision,dimension(NUMAX,1) :: PAR
      double precision,dimension(NDMAX,1) :: FO
      double precision,dimension(NDMAX,3) :: V,S
      double precision,dimension(3,NDMAX) :: G
      double precision :: H, HU, HV
c
      T=0.0d0
      BU=0.0d0
      BV=0.0d0
      BW=0.0d0
      T(3,3)=1.0d0
      BU(3,3)=1.0d0
      BV(2,2)=1.0d0
      BW(1,1)=1.0d0
c
      T(2,2)=PAR(4,1)
      BU(1,1)=cos(PAR(1,1))
      BU(2,2)=cos(PAR(1,1))
      BU(2,1)=sin(PAR(1,1))
      BU(1,2)=-sin(PAR(1,1))
      BV(1,1)=cos(PAR(2,1))
      BV(3,3)=cos(PAR(2,1))
      BV(1,3)=sin(PAR(2,1))
      BV(3,1)=-sin(PAR(2,1))
      BW(2,2)=cos(PAR(3,1))
      BW(3,3)=cos(PAR(3,1))
      BW(3,2)=sin(PAR(3,1))
      BW(2,3)=-sin(PAR(3,1))
c
c     direct calculation of the tensor in the geographic system
c     of coordinates (f) from the a priori in the principal
c     system of coordinates (t)
c     f=b*t*bt, b is decomposed in 3 successives rotations.
c     c=b1*b2, b=c*b3, d ou b=b1*b2*b3
c
      C=matmul(BU,BV)
      B=matmul(C,BW)
      DO I=1,3
        DO J=1,3
          BT(J,I)=B(I,J)
        ENDDO
      ENDDO
      E=matmul(B,T)
      F=matmul(E,BT)
C
C     DIRECT ESTIMATION OF THE NORMALIZED SLIP VECTOR
C
      DO I=1,M
        DO J=1,3
          G(J,I)=F(J,1)*V(I,1)+F(J,2)*V(I,2)+F(J,3)*V(I,3)
        ENDDO
        H=V(I,1)*G(1,I)+V(I,2)*G(2,I)+V(I,3)*G(3,I)
        HU=G(1,I)**2+G(2,I)**2+G(3,I)**2
        HV=S(I,1)*G(1,I)+S(I,2)*G(2,I)+S(I,3)*G(3,I)
        FO(I,1)=HV-SQRT(HU-H**2)
      ENDDO
      RETURN
      END
C----------end of PBDIR------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine TEST : 
c     estimation of the residue of f; FOS=sqrt[sum(f^2)]
c       called by : main program
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      SUBROUTINE TEST(FO,FOS)
      use mod1
      use mod2
      IMPLICIT NONE
      double precision,dimension(NDMAX,1) :: FO
      double precision :: FOS
      integer :: I
c
      FOS=0.0d0
      DO I=1,M
        FOS=FOS+FO(I,1)**2
      ENDDO
      FOS=SQRT(FOS)
      WRITE(IU,206)(FOS)
206   FORMAT(/'RESIDUE OF THE FUNCTION TO NULLIFY = ',D10.3)
      RETURN
      END
C----------end of TEST------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine DERIV : 
c     estimation of the partial deivatives of f
c       called by : main program
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      SUBROUTINE DERIV(PAR,B,V,S,G,F,X,DFO)
      use mod2
      IMPLICIT NONE
      double precision,dimension(NUMAX,1) :: PAR
      double precision, dimension(3,3) :: DBPHI,B,F
      double precision, dimension(MU,3,3) :: DF
      double precision,dimension(NDMAX,NUMAX) :: DNX,DNY,DNZ,DSX
      double precision,dimension(NDMAX,NUMAX) :: DSY,DSZ,DFO
      double precision,dimension(NDMAX,3) :: V,S,X
      double precision,dimension(3,NDMAX) :: G
      double precision :: AA1,BB1,CC1,QUO,ADS,BDS,CDS,DNU,DNV,DNW
      double precision :: DGA,GNB,DGBV,GNA,DSC,DND
      integer :: I,K,I1,I2,K1
c
      DF=0.0d0
cc estimation of the partial derivatives relative to the unknowns (euler+R)
      DBPHI(1,1)=(-cos(PAR(1,1)))*sin(PAR(2,1))
      DBPHI(1,2)=cos(PAR(1,1))*cos(PAR(2,1))*sin(PAR(3,1))
      DBPHI(1,3)=cos(PAR(1,1))*cos(PAR(2,1))*cos(PAR(3,1))
      DBPHI(2,1)=(-sin(PAR(1,1)))*sin(PAR(2,1))
      DBPHI(2,2)=sin(PAR(1,1))*cos(PAR(2,1))*sin(PAR(3,1))
      DBPHI(2,3)=sin(PAR(1,1))*cos(PAR(2,1))*cos(PAR(3,1))
      DBPHI(3,1)=(-cos(PAR(2,1)))
      DBPHI(3,2)=(-sin(PAR(2,1)))*sin(PAR(3,1))
      DBPHI(3,3)=(-sin(PAR(2,1)))*cos(PAR(3,1))
      DF(1,1,1)=(-2.0d0)*(PAR(4,1)*B(1,2)*B(2,2)+B(1,3)*B(2,3))
      DF(1,1,2)=PAR(4,1)*(B(1,2)**2-B(2,2)**2)+B(1,3)**2-B(2,3)**2
      DF(1,1,3)=-(B(3,3)*B(2,3)+PAR(4,1)*B(3,2)*B(2,2))
      DF(1,2,1)=DF(1,1,2)
      DF(1,2,2)=-DF(1,1,1)
      DF(1,2,3)=B(3,3)*B(1,3)+B(3,2)*B(1,2)*PAR(4,1)
      DF(1,3,1)=DF(1,1,3)
      DF(1,3,2)=DF(1,2,3)
      DF(1,3,3)=0.0d0
      DF(2,1,1)=2.0d0*(PAR(4,1)*B(1,2)*DBPHI(1,2)+B(1,3)*DBPHI(1,3))
      DF(2,1,2)=PAR(4,1)*(B(2,2)*DBPHI(1,2)+B(1,2)*DBPHI(2,2))
     $+B(2,3)*DBPHI(1,3)+B(1,3)*DBPHI(2,3)
      DF(2,1,3)=PAR(4,1)*(B(3,2)*DBPHI(1,2)+B(1,2)*DBPHI(3,2))+
     $B(3,3)*DBPHI(1,3)+B(1,3)*DBPHI(3,3)
      DF(2,2,1)=DF(2,1,2)
      DF(2,2,2)=2.0d0*(PAR(4,1)*B(2,2)*DBPHI(2,2)+B(2,3)*DBPHI(2,3))
      DF(2,2,3)=PAR(4,1)*(B(3,2)*DBPHI(2,2)+B(2,2)*DBPHI(3,2))
     $+B(3,3)*DBPHI(2,3)+B(2,3)*DBPHI(3,3)
      DF(2,3,1)=DF(2,1,3)
      DF(2,3,2)=DF(2,2,3)
      DF(2,3,3)=2.0d0*(PAR(4,1)*B(3,2)*DBPHI(3,2)+B(3,3)*DBPHI(3,3))
      DF(3,1,1)=2.0d0*B(1,2)*B(1,3)*(PAR(4,1)-1.0d0)
      AA1=B(2,2)*B(1,3)+B(1,2)*B(2,3)
      DF(3,1,2)=AA1*(PAR(4,1)-1.0d0)
      BB1=B(3,3)*B(1,2)+B(1,3)*B(3,2)
      DF(3,1,3)=BB1*(PAR(4,1)-1.0d0)
      DF(3,2,1)=DF(3,1,2)
      DF(3,2,2)=2.0d0*B(2,2)*B(2,3)*(PAR(4,1)-1.0d0)
      CC1=B(3,3)*B(2,2)+B(2,3)*B(3,2)
      DF(3,2,3)=CC1*(PAR(4,1)-1.0d0)
      DF(3,3,1)=DF(3,1,3)
      DF(3,3,2)=DF(3,2,3)
      DF(3,3,3)=2.0d0*B(3,2)*B(3,3)*(PAR(4,1)-1.0d0)
      DF(4,1,1)=B(1,2)**2
      DF(4,1,2)=B(2,2)*B(1,2)
      DF(4,1,3)=B(3,2)*B(1,2)
      DF(4,2,1)=DF(4,1,2)
      DF(4,2,2)=B(2,2)**2
      DF(4,2,3)=B(3,2)*B(2,2)
      DF(4,3,1)=DF(4,1,3)
      DF(4,3,2)=DF(4,2,3)
      DF(4,3,3)=B(3,2)**2
cc estimation of the partial derivatives relative to the data (str/dp/rk)
      DO 211 I=1,M
      DO 211 K=1,MU
      IF (MU.LE.4) GOTO 212
      QUO=(K-5)/3
      I1=INT(QUO)
      I2=I1+1
      K1=(K-5)-3*I1
c partial derivatives relatives to the unknowns
      IF (I2.NE.I) GOTO 212
c partial derivatives relative to the rake
      IF (K1.EQ.2) GOTO 214
c partial derivatives relatives to the strike
      IF (K1.EQ.0) GOTO 213
c partial derivatives relative to the dip
      DNX(I,K)=-cos(X(I,2))*sin(X(I,1))
      DNY(I,K)=cos(X(I,1))*cos(X(I,2))
      DNZ(I,K)=sin(X(I,2))
      ADS=sin(X(I,3))*sin(X(I,2))
      DSX(I,K)=-ADS*sin(X(I,1))
      DSY(I,K)=ADS*cos(X(I,1))
      DSZ(I,K)=-sin(X(I,3))*cos(X(I,2))
      GOTO 211
213   DNX(I,K)=-sin(X(I,2))*cos(X(I,1))
      DNY(I,K)=-sin(X(I,2))*sin(X(I,1))
      DNZ(I,K)=0.0d0
      BDS=sin(X(I,3))*cos(X(I,2))
      DSX(I,K)=-cos(X(I,3))*sin(X(I,1))+BDS*cos(X(I,1))
      DSY(I,K)=cos(X(I,3))*cos(X(I,1))+BDS*sin(X(I,1))
      DSZ(I,K)=0.0d0
      GOTO 211
212   DNX(I,K)=0.0d0
      DNY(I,K)=0.0d0
      DNZ(I,K)=0.0d0
      DSX(I,K)=0.0d0
      DSY(I,K)=0.0d0
      DSZ(I,K)=0.0d0
      GOTO 211
214   DNX(I,K)=0.0d0
      DNY(I,K)=0.0d0
      DNZ(I,K)=0.0d0
      CDS=cos(X(I,3))*cos(X(I,2))
      DSX(I,K)=-sin(X(I,3))*cos(X(I,1))+CDS*sin(X(I,1))
      DSY(I,K)=-sin(X(I,3))*sin(X(I,1))-CDS*cos(X(I,1))
      DSZ(I,K)=-cos(X(I,3))*sin(X(I,2))
211   CONTINUE
      DO I=1,M
        DO K=1,MU
        DNU=V(I,1)*DF(K,1,1)+V(I,2)*DF(K,1,2)+V(I,3)*DF(K,1,3)
     $+F(1,1)*DNX(I,K)+F(1,2)*DNY(I,K)+F(1,3)*DNZ(I,K)
        DNV=V(I,1)*DF(K,2,1)+V(I,2)*DF(K,2,2)+V(I,3)*DF(K,2,3)
     $+F(2,1)*DNX(I,K)+F(2,2)*DNY(I,K)+F(2,3)*DNZ(I,K)
        DNW=V(I,1)*DF(K,3,1)+V(I,2)*DF(K,3,2)+V(I,3)*DF(K,3,3)
     $+F(3,1)*DNX(I,K)+F(3,2)*DNY(I,K)+F(3,3)*DNZ(I,K)
        DGA=2*G(1,I)*DNU+2*G(2,I)*DNV+2*G(3,I)*DNW
        GNB=V(I,1)*G(1,I)+V(I,2)*G(2,I)+V(I,3)*G(3,I)
        DGBV=2*GNB*(V(I,1)*DNU+V(I,2)*DNV+V(I,3)*DNW
     $+G(1,I)*DNX(I,K)+G(2,I)*DNY(I,K)+G(3,I)*DNZ(I,K))
        GNA=G(1,I)**2+G(2,I)**2+G(3,I)**2
        DSC=(DGA-DGBV)/(2*SQRT(GNA-GNB**2))
        DND=S(I,1)*DNU+S(I,2)*DNV+S(I,3)*DNW
     $+G(1,I)*DSX(I,K)+G(2,I)*DSY(I,K)+G(3,I)*DSZ(I,K)
        DFO(I,K)=DND-DSC
        ENDDO
      ENDDO
      RETURN
      END
C----------end of DERIV------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine ITER : 
c     estimation of the k+1 iteration (evaluetion of x(k+1))
c       called by : main progr
c       call      : PMAT, DMAT, AMAT, DCHOL
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      SUBROUTINE ITER(DFO,FO,PA,PAR,X,SIG)
      use mod2
      IMPLICIT NONE
      integer :: I,K,K00,I11,I22,K11,K22
      double precision, dimension(NDMAX,NUMAX) :: DFO
      double precision, dimension(NUMAX,NDMAX) :: DFOT,CSS
      double precision, dimension(NUMAX,NUMAX) :: SIG
      double precision, dimension(NDMAX,NDMAX) :: CVV
      double precision, dimension(NUMAX,1) :: PAR,PA,PAI,CYY
      double precision, dimension(NDMAX,1) :: DPA,FO,SFO,CVW
      double precision, dimension(NDMAX,3) :: X
      double precision :: QUOU
c
      DO I=1,M
        DO K=1,MU
          DFOT(K,I)=DFO(I,K)
        ENDDO
      ENDDO
      CSS(1:MU,1:M)=matmul(SIG(1:MU,1:MU),DFOT(1:MU,1:M))
      CVV(1:M,1:M)=matmul(DFO(1:M,1:MU),CSS(1:MU,1:M))
      DO  I=1,M
        CVV(I,I)=CVV(I,I)+0.222D-08
      ENDDO
      PAI=PAR-PA
      DPA(1:M,1:1)=matmul(DFO(1:M,1:MU),PAI(1:MU,1:1))
      SFO=DPA-FO
      CALL DCHOL(CVV,SFO,CVW)
      CYY(1:MU,1:1)=matmul(CSS(1:MU,1:M),CVW(1:M,1:1))
      PAR=PA+CYY
      DO K00=5,MU
        QUOU=(K00-5)/3
        I11=INT(QUOU)
        I22=I11+1
        K11=(K00-5)-3*I11
        K22=K11+1
        X(I22,K22)=PAR(K00,1)
      ENDDO
      RETURN
      END
C----------end of ITER------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine DCHOL : 
c     estimation of the inverse of FC0F' and evaluation
c     of (FC0F')^(-1)*[F(x-x0)-f(x)]
c       called by : ITER
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      SUBROUTINE DCHOL(CVV,SFO,CVW)
      use mod2
      IMPLICIT NONE
      integer :: I,J,L1,M1,K,L,M2,L2,NA,IA,LU
      double precision :: S,SOM,SOU
      double precision, dimension(NDMAX,NDMAX) :: BI,CVV,CWW
      double precision, dimension(NDMAX,1) :: SFO,SFU,CVW
c
      BI(1,1)=SQRT(CVV(1,1))
      DO I=2,M
        BI(1,I)=CVV(1,I)/BI(1,1)
      ENDDO
      DO J=2,M
        L1=J-1
        M1=J+1
        S=0.0d0
        DO K=1,L1
          S=S+BI(K,J)**2
        ENDDO
        BI(J,J)=SQRT(CVV(J,J)-S)
        IF (J.EQ.M) GO TO 42
        DO I=M1,M
          SOM=0.0d0
          DO K=1,L1
            SOM=SOM+BI(K,J)*BI(K,I)
          ENDDO
          BI(J,I)=(CVV(J,I)-SOM)/BI(J,J)
        ENDDO
      ENDDO
42    CONTINUE
      DO J=2,M
        L=J-1
        DO I=1,L
          BI(J,I)=0.0d0
        ENDDO
      ENDDO
      DO I=1,M
        DO J=1,M
          CWW(I,J)=BI(J,I)
        ENDDO
      ENDDO
      DO I=1,M
        CVV(I,I)=1./CWW(I,I)
        M2=I+1
        IF (M2.GT.M) GO TO 100
        DO J=M2,M
          CVV(I,J)=0.0d0
        ENDDO
      ENDDO
100   DO I=2,M
        L2=I-1
        DO J=1,L2
          S=0.0d0
          DO K=1,L2
            S=S+CWW(I,K)*CVV(K,J)
          ENDDO
          CVV(I,J)=-(1./CWW(I,I))*S
        ENDDO
      ENDDO
      SFU(1:M,1:1)=matmul(CVV(1:M,1:M),SFO(1:M,1:1))
      CVW(M,1)=SFU(M,1)/BI(M,M)
      NA=M-1
      DO J=1,NA
        I=M-J
        IA=I+1
        SOU=0.0d0
        DO 221 LU=IA,M
        K=M+IA-LU
221     SOU=SOU+CVW(K,1)*BI(I,K)
        CVW(I,1)=(SFU(I,1)-SOU)/BI(I,I)
      ENDDO
      RETURN
      END
C----------end of DCHOL------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine CRITER : 
c     estimation of (x-x0)'C0^(-1)(x-x0)
c       called by : main program
c       call      : PMAT, DMAT
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      SUBROUTINE CRITER(PAR,PA,SSIG)
      use mod1
      use mod2
      IMPLICIT NONE
      integer :: K
      double precision, dimension(NUMAX,1) :: PAR, PA, DPR
      double precision, dimension(1,NUMAX) :: DPRT, DIS
      double precision, dimension(NUMAX,NUMAX) :: SSIG
      double precision, dimension(1,1) :: SOL=0.0d0
c
      DPR=PAR-PA
      DO K=1,MU
        DPRT(1,K)=DPR(K,1)
      ENDDO
      DIS(1:1,1:MU)=matmul(DPRT(1:1,1:MU),SSIG(1:MU,1:MU))
      SOL(1:1,1:1)=matmul(DIS(1:1,1:MU),DPR(1:MU,1:1))
      WRITE(IU,201) SOL(1,1)
201   FORMAT(/'CRITERE TO MINIMIZE = ',D10.3)
      RETURN
      END
C----------end of CRITER------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine POSTMA : 
c     estimation of the a posteriori covariance matrix
c       called by : main program
c       call      : PMAT, DMAT
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      SUBROUTINE POSTMA(DFO,SIG,CP)
      use mod2
      IMPLICIT NONE
      integer :: I,K,J
      double precision :: PI
      double precision, dimension(NDMAX,NUMAX):: DFO,CUU,CZZ
      double precision, dimension(NUMAX,NUMAX):: SIG,CRR,CP
      double precision, dimension(NUMAX,NDMAX):: DFOT,CSS
      double precision, dimension(NDMAX,NDMAX):: CVV,CWW
c
      PI=3.1415926536d0
c
      CUU(1:M,1:MU)=matmul(DFO(1:M,1:MU),SIG(1:MU,1:MU))
      DO I=1,M
        DO K=1,MU
          DFOT(K,I)=DFO(I,K)
        ENDDO
      ENDDO
      CVV(1:M,1:M)=matmul(CUU(1:M,1:MU),DFOT(1:MU,1:M))
      DO I=1,M
        CVV(I,I)=CVV(I,I)+0.222D-08
      ENDDO
      CALL DCHOLI(CVV,CWW)
      CZZ(1:M,1:MU)=matmul(CWW(1:M,1:M),CUU(1:M,1:MU))
      CSS(1:MU,1:M)=matmul(SIG(1:MU,1:MU),DFOT(1:MU,1:M))
      CRR(1:MU,1:MU)=matmul(CSS(1:MU,1:M),CZZ(1:M,1:MU))
c CP=SIG-SIG.DFOT(DFO.SIG.DFOT)^(-1).DFO.SIG
      CP=SIG-CRR
      DO I=1,3
        DO J=1,3
          CP(I,J)=CP(I,J)*180.0d0/PI
        ENDDO
      ENDDO
      RETURN
      END
C----------end of POSTMA------------------------------
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     subroutine DCHOLI : 
c     estimation of the inverse of (FC0F')
c       called by : POSTMA
c       call      : none
cccccccccccccccccccccccccccccccccccccccccccccccccccccc
      SUBROUTINE DCHOLI(CVV,CWW)
      use mod2
      IMPLICIT NONE
      integer :: I,L1,M1,J,K,L,M2,L2
      double precision :: S,SOM
      double precision, dimension(NDMAX,NDMAX) :: BI,CVV,CWW
c
      BI(1,1)=SQRT(CVV(1,1))
      DO I=2,M
        BI(1,I)=CVV(1,I)/BI(1,1)
      ENDDO
      DO J=2,M
        L1=J-1
        M1=J+1
        S=0.
        DO K=1,L1
          S=S+BI(K,J)**2
        ENDDO
        BI(J,J)=SQRT(CVV(J,J)-S)
        IF (J.EQ.M) GO TO 42
        DO I=M1,M
          SOM=0.0d0
          DO K=1,L1
            SOM=SOM+BI(K,J)*BI(K,I)
          ENDDO
          BI(J,I)=(CVV(J,I)-SOM)/BI(J,J)
        ENDDO
      ENDDO
42    CONTINUE
      DO J=2,M
        L=J-1
        DO I=1,L
          BI(J,I)=0.0d0
        ENDDO
      ENDDO
      DO J=1,M
        DO I=1,M
          CWW(I,J)=BI(J,I)
        ENDDO
      ENDDO
      DO I=1,M
        BI(I,I)=1./CWW(I,I)
        M2=I+1
        IF (M2.GT.M) GO TO 100
        DO J=M2,M
          BI(I,J)=0.0d0
        ENDDO
      ENDDO
100   DO I=2,M
        L2=I-1
        DO J=1,L2
          S=0.0d0
          DO K=1,L2
            S=S+CWW(I,K)*BI(K,J)
          ENDDO
          BI(I,J)=-(1./CWW(I,I))*S
        ENDDO
      ENDDO
45    CONTINUE
      DO J=1,M
        DO I=1,M
          CVV(I,J)=BI(J,I)
        ENDDO
      ENDDO
      DO J=1,M
        DO I=1,M
          CWW(I,J)=0.0d0
          DO K=1,M
            CWW(I,J)=CWW(I,J)+CVV(I,K)*BI(K,J)
          ENDDO
        ENDDO
      ENDDO
      RETURN
      END
C----------end of DCHOLI------------------------------
